#!/usr/bin/env python3

## BACKEND
import sys
import os
import glob
import json
import textwrap
import time
import webbrowser

## APP
import mzml2isa.isa
import mzml2isa.mzml

## FRONTEND
from PyQt5.QtWidgets import * #QApplication, QMainWindow
from PyQt5.QtCore import *
from PyQt5.QtGui import QPalette

## UI
from nmrml2isa_qt.qt.main import Ui_MainWindow

## UI MODULES
from nmrml2isa_qt.usermeta import UserMetaDialog
from nmrml2isa_qt.parserprogress import ParserProgressDialog



class MainWindow(QMainWindow):


    def __init__(self, parent=None):
        super(MainWindow, self).__init__(parent)

        # Set up the user interface from Designer.
        self.ui = Ui_MainWindow()
        self.ui.setupUi(self)

        # Connect up the buttons.
        self.ui.PushBut_convert.clicked.connect(self.launchParser)
        self.ui.toolButton_input_explore.clicked.connect(self.exploreInput)
        self.ui.toolButton_output_explore.clicked.connect(self.exploreOutput)
        self.ui.toolButton_metadata.clicked.connect(self.getUserMeta)
        self.ui.toolButton_help.clicked.connect(self.openHelp)

        # Connect up the checkboxes
        self.ui.cBox_multiple.stateChanged.connect(self.toggleMultiple)
        self.ui.cBox_export.stateChanged.connect(self.toggleExport)

        # init some attributes
        self.userMeta = {}

    def toggleMultiple(self, int):
        """ Toggle the Study LineEdit when multiple studies checkbox is checked """
        if self.ui.cBox_multiple.isChecked():
            self.ui.lineEdit_study.setEnabled(False)
            self.ui.lineEdit_study.setText("")
            self.ui.lbl_study_error.setText("")
        else:
            if not self.ui.cBox_export.isChecked():
                self.ui.lineEdit_study.setEnabled(True)

    def toggleExport(self, int):
        """ Toggle the Study LineEdit when export studies checkbox is checked """
        if self.ui.cBox_export.isChecked():

            self.ui.lineEdit_output.setEnabled(False)
            self.ui.lineEdit_output.setText("")
            self.ui.lbl_output_error.setText("")
            self.ui.toolButton_output_explore.setEnabled(False)

            self.ui.lineEdit_study.setEnabled(False)
            self.ui.lineEdit_study.setText("")
            self.ui.lbl_study_error.setText("")

        else:
            self.ui.lineEdit_output.setEnabled(True)
            self.ui.toolButton_output_explore.setEnabled(True)
            if not self.ui.cBox_multiple.isChecked():
                self.ui.lineEdit_study.setEnabled(True)

    def launchParser(self):
        """Checks if arguments are ok, then launches the parser window"""

        LEGIT, inputDir, outputDir, studyName = self.checkArgs()
        if not LEGIT: return

        # Open the progress window
        self.progress = ParserProgressDialog(inputDir, outputDir, studyName, self.userMeta)
        self.progress.exec_()

        # Resets field after parser was launched
        self.ui.lineEdit_input.setText("")
        self.ui.lineEdit_output.setText("")
        self.ui.lineEdit_study.setText("")

    def exploreInput(self):
        """Open file explorer and fills the input field"""
        directory = str(QFileDialog.getExistingDirectory(self, "Select Directory"))
        self.ui.lineEdit_input.setText(directory)

    def exploreOutput(self):
        """Open file explorer and fills the output field"""
        directory = str(QFileDialog.getExistingDirectory(self, "Select Directory"))
        self.ui.lineEdit_output.setText(directory)

    def checkArgs(self):
        """Check for arguments and displays errors if any"""
        inputDir = os.path.expanduser(self.ui.lineEdit_input.text())
        outputDir = os.path.expanduser(self.ui.lineEdit_output.text())
        studyName = self.ui.lineEdit_study.text()
        LEGIT = True

        # inputDir errors checking
        if not inputDir:
            self.ui.lbl_input_error.setText("Please provide a directory")
            LEGIT = False
        elif not os.path.isdir(inputDir):
            self.ui.lbl_input_error.setText("Directory does not exist")
            LEGIT = False
        elif not os.access(inputDir, os.R_OK):
            self.ui.lbl_input_error.setText("Directory has no read permissions")
            LEGIT = False
        elif not self.ui.cBox_multiple.isChecked():
            # list nmrML files in study folder
            if not [x for x in os.listdir(inputDir) if x[-5:].upper() == "NMRML"]:
                self.ui.lbl_input_error.setText("Directory contains no nmrML files")
                LEGIT = False
            else:
                self.ui.lbl_input_error.setText("")
        elif self.ui.cBox_export.isChecked() and not os.access(inputDir, os.W_OK):
            self.ui.lbl_input_error.setText("Directory has no write permissions")
            LEGIT = False
        else:
            self.ui.lbl_input_error.setText("")

        # OutputDir errors checking
        if self.ui.lineEdit_output.isEnabled():
            if not outputDir:
                self.ui.lbl_output_error.setText("Please provide a directory")
                LEGIT = False
            elif not os.path.isdir(outputDir):
                self.ui.lbl_output_error.setText("Directory does not exist")
                LEGIT = False
            elif not os.access(outputDir, os.W_OK):
                self.ui.lbl_output_error.setText("Directory has no write permissions")
                LEGIT = False
            else:
                self.ui.lbl_output_error.setText("")
        else:
            self.ui.lbl_output_error.setText("")

        # StudyName errors checking
        if self.ui.lineEdit_study.isEnabled() and not studyName:
            self.ui.lbl_study_error.setText("Please provide a study name")
            LEGIT = False
        else:
            self.ui.lbl_study_error.setText("")

        return LEGIT, inputDir, outputDir, studyName

    def getUserMeta(self):
        if not hasattr(self, 'userMeta'):
            self.userMeta = {}
        self.userMetaDialog = UserMetaDialog(self, self.userMeta)
        self.userMetaDialog.SigUpdateMetadata.connect(self.updateMetadata)
        self.userMetaDialog.exec_()

    def updateMetadata(self, json_metadata):
        self.userMeta = json.loads(json_metadata)

    def openHelp(self):
        rtd = "http://2isa.readthedocs.io/en/latest/nmrml2isa-qt/"
        webbrowser.open(rtd, new=2)


def main():
    app = QApplication(sys.argv)
    mainwindow = MainWindow()
    mainwindow.show()
    sys.exit(app.exec_())

if __name__ == '__main__':
    main()



#!/usr/bin/env python3

## BACKEND
import sys
import os
import json
from copy import deepcopy
from collections import OrderedDict, Mapping

## FRONTEND
from PyQt5.QtWidgets import *
from PyQt5.QtCore import *
from PyQt5.QtGui import QPalette

## APP
#from mzml2isa.versionutils import dict_update

## UI
from imzml2isa_qt.qt.contact import Ui_Dialog as Ui_Contact

## UI MODULES
from imzml2isa_qt.scrapers import PROThread



# Default contact dict
CONTACT = OrderedDict([
			('first_name', ''), ('mid', ''), ('last_name',''),
			('phone',''), ('email',''), ('fax',''), ('affiliation',''),
			('adress',''),
			('roles',{'accession':'', 'ref':'', 'name':''}),
		  ])


def dict_update(d, u):
    """Update a nested dictionnary of various depth

    Shamelessly taken from here: http://stackoverflow.com/a/3233356/623424
    And updated to work with dictionaries nested in lists.
    """
    for k, v in u.items():
        if isinstance(v, Mapping):
            r = dict_update(d.get(k, {}), v)
            d[k] = r
        elif isinstance(v, list):
            r = []
            for x in v:                      # v Mandatory because of Python linking lists
                r.append(dict_update(deepcopy(d[k][0]), deepcopy(x)))
            d[k] = r
        else:
            d[k] = u[k]
    return d


class ContactDialog(QDialog):
    """Add or edit a contact"""

    def __init__(self, parent=None, jsoncontact=None):
        super(ContactDialog, self).__init__(parent)
        self.ui = Ui_Contact()
        self.ui.setupUi(self)

        # Launch Publishing Roles Ontology scraper
        self.PROscraper = PROThread()
        self.PROscraper.Finished.connect(self.fillPROComboBox)
        self.PROscraper.start()

        # Connect buttons
        self.ui.buttonBox.button(QDialogButtonBox.Ok).clicked.connect(self.onOkClicked)
        self.ui.buttonBox.button(QDialogButtonBox.Cancel).clicked.connect(self.reject)

        # Try to load existing contact info & fill fields
        self.contact = json.loads(jsoncontact) if jsoncontact is not None else dict(deepcopy(CONTACT))
        self.fillFields()

        self.ui.first_name.setFocus()

    def fillFields(self):
        """Fill fields with known information"""
        for (key, value) in self.contact.items():
            if key not in ('roles', 'adress'):
                getattr(self.ui, key).setText(value)
            elif key == 'adress':
                self.ui.adress.setPlainText(value)

    def fillPROComboBox(self, jsontology):
        """Fill pro combobox with scraped information"""
        _translate = QCoreApplication.translate
        # Get PRO ontology
        self.ontoPRO = json.loads(jsontology)
        self.ontoPROk = sorted(self.ontoPRO)
        # Hide roles fields (they ARE useful, though !)
        self.ui.roles.hide()
        # Hide "connecting to PRO" labels
        self.ui.label_pro.hide()
        # Add status to combo box
        for i, status in enumerate(self.ontoPROk):
            self.ui.combo_roles.addItem("")
            self.ui.combo_roles.setItemText(i, _translate("Dialog", status))
        # Check if value to display
        if self.contact['roles']['value']:
            self.ui.combo_roles.setCurrentText(self.contact['roles']['name'])
            self.ui.roles.setText(self.contact['roles']['accession'])
        else:
            self.ui.combo_roles.setCurrentIndex(-1)
            self.ui.roles.setText('')
        # Link comboboxes and display fields
        self.ui.combo_roles.activated.connect(lambda x: self.ui.roles.setText(\
          self.ontoPRO[self.ui.combo_roles.currentText()]))
        # Enable comboboxes
        self.ui.combo_roles.setEnabled(True)

    def getFields(self):
        """Get contact information from Dialog fields"""
        for key in self.contact.keys():
            if key not in ('roles', 'adress'):
                self.contact[key] = getattr(self.ui, key).text() or ''
            elif key == 'adress':
                self.contact['adress'] = self.ui.adress.toPlainText() or ''

        self.contact['roles']['name'] = self.ui.combo_roles.currentText() if self.ui.roles.text() else ''
        self.contact['roles']['accession'] = self.ui.roles.text()
        self.contact['roles']['ref'] = 'PRO' if self.ui.roles.text() else ''

    def onOkClicked(self):
        self.getFields()
        self.accept()

if __name__ == '__main__':

    app = QApplication(sys.argv)
    um = ContactDialog()
    um.exec_()
    um = ContactDialog()
    um.exec_()
    print(um.contact)



## BACKEND
import sys
import os
import json
import urllib.error
import urllib.request as rq
from urllib.parse import quote

## FRONTEND
from PyQt5.QtCore import QThread, pyqtSignal



class SparOntologyThread(QThread):

    Finished = pyqtSignal('QString')

    def __init__(self):
        super(SparOntologyThread, self).__init__()

    def run(self):
        try:
            onto = json.loads(rq.urlopen(self.jsonSourceUrl).read().decode('utf-8'))
            info = []
            for x in onto:
                if '@type' in x:
                    if self.ontoClass in x['@type']:
                        info.append(x)
            info = [ (x['http://www.w3.org/2000/01/rdf-schema#label'],x['@id']) for x in info ]
            info = json.dumps({x[0]['@value'].capitalize():y for (x,y) in info})
        except: #urllib.error.URLError:
            with open(os.path.join(os.path.dirname(__file__), os.path.join("ontologies", self.sparName + os.path.extsep + 'json')), 'r') as f:
                info = f.read()
        finally:
            self.Finished.emit(info)


class PSOThread(SparOntologyThread):
    """A thread to scrape the Publishing Status Ontology"""

    def __init__(self):
        super(PSOThread, self).__init__()
        self.jsonSourceUrl = "http://www.sparontologies.net/ontologies/pso/source.json"
        self.sparName = "pso"
        self.ontoClass = "http://purl.org/spar/pso/PublicationStatus"


class PROThread(SparOntologyThread):
    """A thread to scrape the Publishing Roles Ontology"""
    def __init__(self):
        super(PROThread, self).__init__()
        self.jsonSourceUrl = "http://www.sparontologies.net/ontologies/pro/source.json"
        self.sparName = "pro"
        self.ontoClass = "http://purl.org/spar/pro/PublishingRole"



class OlsSearcher(QThread):
    """A thread that searches the Ontology Lookup Service."""

    Finished = pyqtSignal('QString')

    def __init__(self, query, rows=200):
        super(OlsSearcher, self).__init__()
        self.searchUrl = "http://www.ebi.ac.uk/ols/api/search/?q={}"\
            "&groupField=1&rows={}".format(query, rows)

    def run(self):
        try:
            request = rq.FancyURLopener({})
            with request.open(self.searchUrl) as url_opener:
                result = json.loads(url_opener.read().decode('utf-8'))
            
                if not 'response' in result or result['response']['numFound'] == 0:
                    answer = ('')
                else:
                    answer = json.dumps(result['response']['docs'])
                    
        except:
            answer = ''
        finally:
            self.Finished.emit(answer)


class OlsExplorer(QThread):
    """A thread that get the informations of a class based on its iri."""
  
    Finished = pyqtSignal('QString', 'QString')

    def __init__(self, short_ref, prefix, iri, ):
        super(OlsExplorer, self).__init__()
        self.ref = short_ref
        self.url = 'http://www.ebi.ac.uk/ols/api/ontologies/{prefix}' \
                    '/terms/{iri}'.format(prefix=prefix, 
                                          iri=quote(quote(iri, safe=''), safe='')
                                          )


    def run(self):
        try:
            request = rq.FancyURLopener({})
            with request.open(self.url) as url_opener:
                self.result = url_opener.read().decode('utf-8')
        except urllib.error:
            self.result = ''
        finally:
            self.Finished.emit(self.ref, self.result)


class OlsOntologist(QThread):
    """A thread that get the informations of an ontology based on its prefix."""
   
    Finished = pyqtSignal('QString', 'QString')

    def __init__(self, prefix, parent=None, *args, **kwargs):
        super(OlsOntologist, self).__init__(parent, *args, **kwargs)
        self.prefix = prefix
        self.url = 'http://www.ebi.ac.uk/ols/api/ontologies/{prefix}'.format(prefix=prefix) 


    def run(self):
        try:
            request = rq.FancyURLopener({})
            with request.open(self.url) as url_opener:
                result = json.loads(url_opener.read().decode('utf-8'))
                self.config = result['config']
        except urllib.error:
            self.result = ''
        finally:
            self.Finished.emit(self.prefix, json.dumps(self.config))





#!/usr/bin/env python3

## BACKEND
import os
import sys
import json
from copy import deepcopy

## FRONTEND
from PyQt5.QtWidgets import * #QApplication, QMainWindow
from PyQt5.QtCore import *
from PyQt5.QtGui import QPalette, QStandardItemModel, QStandardItem

# UI
from nmrml2isa_qt.qt.usermeta import Ui_Dialog as Ui_UserMeta

# UI_MODULES
from nmrml2isa_qt.ols import OlsDialog
from nmrml2isa_qt.contact import ContactDialog, CONTACT, dict_update
from nmrml2isa_qt.scrapers import PSOThread


# Suffixes for qt fields
SUFFIX = {'study':'', 'investigation':'_2'}


UNIT = {
            'mm': {'name':'millimeter', 'ref':'UO', 'accession':'http://purl.obolibrary.org/obo/UO_0000016'},
            'nm': {'name':'nanometer', 'ref':'UO', 'accession':'http://purl.obolibrary.org/obo/UO_0000018'},
            'pm': {'name':'picometer', 'ref':'UO', 'accession':'http://purl.obolibrary.org/obo/UO_0000020'},
            'µm': {'name':'micrometer', 'ref':'UO', 'accession':'http://purl.obolibrary.org/obo/UO_0000017'},
        }



USERMETA = {'characteristics':           {'organism': {'name':'', 'accession':'', 'ref':''},
                                          'organism_variant':  {'name':'', 'accession':'', 'ref':''},
                                          'organism_part':     {'name':'', 'accession':'', 'ref':''},
                                         },
            'investigation':             {'identifier': '', 'title': 'Investigation', 'description': '',
                                          'submission_date':'', 'release_date':''
                                         },
            'investigation_publication': {'pubmed': '', 'doi': '', 'author_list': '', 'title':'',
                                          'status': {'name':'', 'accession':'', 'ref':'PSO'},
                                         },

            'study':                     {
                                          'title': '', 'description': '', 'submission_date':'', 'release_date':'',
                                         },
            'study_publication':         {'pubmed': '', 'doi': '', 'author_list': '', 'title':'',
                                          'status': {'name':'', 'accession':'', 'ref':'PSO'},
                                         },

            'description':               {'extraction':'', 'nmr_sample':'', 'nmr_spec':'',
                                          'nmr_assay':'', 'data_trans':'', 'metabo_id':'',
                                          'sample_collec':'',
                                         },




            #Multiple Values Parameters
            'study_contacts':            [
                                            {'first_name': '', 'last_name': '', 'mid':'', 'email':'',
                                             'fax': '', 'phone':'', 'adress':'', 'affiliation':'',
                                             'roles': {'name':'', 'accession':'', 'ref':''},
                                            },
                                         ],

            'investigation_contacts':    [
                                            {'first_name': '', 'last_name': '', 'mid':'', 'email':'',
                                             'fax': '', 'phone':'', 'adress':'', 'affiliation':'',
                                             'roles': {'name':'', 'accession':'', 'ref':''},
                                            },
                                         ],

            'Extraction Method':           {'name':'', 'ref':'', 'accession':''},
            'Solvent':                     {'name':'', 'ref':'', 'accession':''},
            'Sample pH':                   {'value':''},
            'Label':                       {'name':'', 'ref':'', 'accession':''},

}



class UserMetaDialog(QDialog):

    SigUpdateMetadata = pyqtSignal('QString')

    def __init__(self, parent=None, metadata={}):

        super(UserMetaDialog, self).__init__(parent)

        self.ui = Ui_UserMeta()
        self.ui.setupUi(self)

        # Update metadata with user submitted ones
        self.metadata = dict_update(USERMETA, metadata)

        # Connect dialog buttons
        self.ui.buttonBox.button(QDialogButtonBox.Apply).clicked.connect(self.save)
        self.ui.buttonBox.button(QDialogButtonBox.Ok).clicked.connect(self.saveandquit)
        self.ui.buttonBox.button(QDialogButtonBox.Cancel).clicked.connect(self.reject)

        # Connect Contacts buttons
        self.ui.add_contact.clicked.connect(lambda: self.addContact('study'))
        self.ui.rm_contact.clicked.connect(lambda: self.rmContact('study'))
        self.ui.edit_contact.clicked.connect(lambda: self.editContact('study'))
        self.ui.add_contact_2.clicked.connect(lambda: self.addContact('investigation'))
        self.ui.rm_contact_2.clicked.connect(lambda: self.rmContact('investigation'))
        self.ui.edit_contact_2.clicked.connect(lambda: self.editContact('investigation'))

        # Connect Characteristics buttons
        self.ui.search_organism.clicked.connect(lambda: self.searchCvTerm('organism'))
        self.ui.search_organism_part.clicked.connect(lambda: self.searchCvTerm('organism_part'))
        self.ui.search_organism_variant.clicked.connect(lambda: self.searchCvTerm('organism_variant'))
        self.ui.rm_organism.clicked.connect(lambda: self.rmCvTerm('organism'))
        self.ui.rm_organism_part.clicked.connect(lambda: self.rmCvTerm('organism_part'))
        self.ui.rm_organism_variant.clicked.connect(lambda: self.rmCvTerm('organism_variant'))

        # Connect Material / Methods
        self.ui.search_extraction_method.clicked.connect(lambda: self.searchCvTerm('extraction_method'))
        self.ui.search_solvent.clicked.connect(lambda: self.searchCvTerm('solvent'))
        self.ui.search_label.clicked.connect(lambda: self.searchCvTerm('label'))
        self.ui.rm_extraction_method.clicked.connect(lambda: self.rmCvTerm('extraction_method'))
        self.ui.rm_solvent.clicked.connect(lambda: self.rmCvTerm('solvent'))
        self.ui.rm_label.clicked.connect(lambda: self.rmCvTerm('label'))

        # Setup Contacts model / view
        self.ui.model_contacts = QStandardItemModel(0,11)
        self.ui.table_contacts.setModel(self.ui.model_contacts)
        self.ui.table_contacts.horizontalHeader().setSectionResizeMode(QHeaderView.ResizeToContents)
        self.ui.model_contacts_2 = QStandardItemModel(0,11)
        self.ui.table_contacts_2.setModel(self.ui.model_contacts_2)
        self.ui.table_contacts_2.horizontalHeader().setSectionResizeMode(QHeaderView.ResizeToContents)

        # Start PSO scraper
        self.PSOscraper = PSOThread()
        self.PSOscraper.Finished.connect(self.fillPSOComboBoxes)
        self.PSOscraper.start()

        # Fill fields with known values
        self.setUpDates()
        self.fillFields()

        self.ui.buttonBox.button(QDialogButtonBox.Apply).setFocus()


    def setUpDates(self):
        """Connect dates changed events"""
        self.dates_changed = {x:False for x in ('s_rel', 's_sub', 'i_rel', 'i_sub')}
        self.ui.submission_date.editingFinished.connect(lambda: self.setDateChanged('s_sub'))
        self.ui.release_date.editingFinished.connect(lambda: self.setDateChanged('s_rel'))
        self.ui.submission_date_2.editingFinished.connect(lambda: self.setDateChanged('i_sub'))
        self.ui.release_date_2.editingFinished.connect(lambda: self.setDateChanged('i_rel'))

    def setDateChanged(self, date):
        """Registers a date was changed."""
        self.dates_changed[date] = True

    def save(self):
        """Save values stored in dialog fields"""
        self.getFields()
        self.SigUpdateMetadata.emit(json.dumps(self.metadata))

    def saveandquit(self):
        """Save values and close dialog"""
        self.save()
        self.accept()

    def fillFields(self):
        """Fill dialog fields with known information"""

        ## STUDY
        ### General
        self.ui.title.setText(self.metadata['study']['title'])
        self.ui.description.setPlainText(self.metadata['study']['description'])
        if self.metadata['study']['submission_date']:
            self.ui.submission_date.setDate(QDate.fromString(self.metadata['study']['submission_date'], "yyyy-MM-dd"))
            self.setDateChanged('s_sub')
        if self.metadata['study']['release_date']:
            self.ui.release_date.setDate(QDate.fromString(self.metadata['study']['release_date'], "yyyy-MM-dd"))
            self.setDateChanged('s_rel')
        ### Publication
        self.ui.pubmed_id.setText(self.metadata['study_publication']['pubmed'])
        self.ui.doi.setText(self.metadata['study_publication']['doi'])
        self.ui.pub_title.setText(self.metadata['study_publication']['title'])
        self.ui.authors_list.setPlainText(self.metadata['study_publication']['author_list'])
        ### Contact
        self.fillContacts(self.metadata['study_contacts'], 'study')

        ## INVESTIGATION
        ### General
        self.ui.identifier_2.setText(self.metadata['investigation']['identifier'])
        self.ui.description_2.setPlainText(self.metadata['investigation']['description'])
        if self.metadata['investigation']['submission_date']:
            self.ui.submission_date_2.setDate(QDate.fromString(self.metadata['investigation']['submission_date'], "yyyy-MM-dd"))
            self.setDateChanged('i_sub')
        if self.metadata['investigation']['release_date']:
            self.ui.release_date_2.setDate(QDate.fromString(self.metadata['investigation']['release_date'], "yyyy-MM-dd"))
            self.setDateChanged('i_rel')
        ### Publication
        self.ui.pubmed_id_2.setText(self.metadata['investigation_publication']['pubmed'])
        self.ui.doi_2.setText(self.metadata['investigation_publication']['doi'])
        self.ui.pub_title_2.setText(self.metadata['investigation_publication']['title'])
        self.ui.authors_list_2.setPlainText(self.metadata['investigation_publication']['author_list'])
        ### Contact
        self.fillContacts(self.metadata['study_contacts'], 'investigation')

        ## EXPERIMENTS
        ### Characteristics
        for key in self.metadata['characteristics'].keys():
            for ontokey in ('name', 'accession', 'ref'):
                getattr(self.ui, ontokey+'_'+key).setText(self.metadata['characteristics'][key][ontokey])

        ### Descriptions
        for (key, value) in self.metadata['description'].items():
            getattr(self.ui, key + '_desc').setPlainText(value)

        ## MATERIAL/METHODS
        for key in ('Extraction Method', 'Label', 'Solvent'):
            for ontokey in ('name', 'accession', 'ref'):
                getattr(self.ui, ontokey+'_'+key.lower().replace(' ', '_')).setText(self.metadata[key][ontokey])
        self.ui.value_sample_pH.setText(self.metadata['Sample pH']['value'])


    def getFields(self):
        """Get intel from dialog fields."""

        ## STUDY
        ### General
        self.metadata['study']['title'] = self.ui.title.text()
        self.metadata['study']['identifier'] = self.ui.identifier.text()
        self.metadata['study']['description'] = self.ui.description.toPlainText()
        self.metadata['study']['submission_date'] = self.ui.submission_date.date().toString("yyyy-MM-dd") if self.dates_changed['s_sub'] else ''
        self.metadata['study']['release_date'] = self.ui.release_date.date().toString("yyyy-MM-dd") if self.dates_changed['s_rel'] else ''
        ### Publication
        self.metadata['study_publication']['pubmed'] = self.ui.pubmed_id.text()
        self.metadata['study_publication']['doi'] = self.ui.doi.text()
        self.metadata['study_publication']['title'] = self.ui.pub_title.text()
        self.metadata['study_publication']['author_list'] = self.ui.authors_list.toPlainText()
        self.metadata['study_publication']['status']['name'] = self.ui.combo_status.currentText() if self.ui.status.text() else ''
        self.metadata['study_publication']['status']['accession'] = self.ui.status.text()
        self.metadata['study_publication']['status']['ref'] = 'PSO' if self.ui.status.text() else ''
        ### Contact
        self.getContactFields('study')

        ## INVESTIGATION
        ### General
        self.metadata['investigation']['identifier'] = self.ui.identifier_2.text()
        self.metadata['investigation']['description'] = self.ui.description_2.toPlainText()
        self.metadata['investigation']['submission_date'] = self.ui.submission_date_2.date().toString("yyyy-MM-dd") if self.dates_changed['i_sub'] else ''
        self.metadata['investigation']['release_date'] = self.ui.release_date_2.date().toString("yyyy-MM-dd") if self.dates_changed['i_rel'] else ''
        ### Publication
        self.metadata['investigation_publication']['pubmed'] = self.ui.pubmed_id_2.text()
        self.metadata['investigation_publication']['doi'] = self.ui.doi_2.text()
        self.metadata['investigation_publication']['title'] = self.ui.pub_title_2.text()
        self.metadata['investigation_publication']['author_list'] = self.ui.authors_list_2.toPlainText()
        self.metadata['investigation_publication']['status']['name'] = self.ui.combo_status_2.currentText() if self.ui.status_2.text() else ""
        self.metadata['investigation_publication']['status']['accession'] = self.ui.status_2.text()
        self.metadata['investigation_publication']['status']['ref'] = 'PSO' if self.ui.status_2.text() else ''
        ### Contact
        self.getContactFields('investigation')

        ## EXPERIMENTS
        ## Characteristics
        for key in self.metadata['characteristics'].keys():
            for ontokey in ('name', 'accession', 'ref'):
                self.metadata['characteristics'][key][ontokey] = getattr(self.ui, ontokey+'_'+key).text()

        ### Descriptions
        for key in self.metadata['description'].keys():
            self.metadata['description'][key] = getattr(self.ui, key+'_desc').toPlainText()

        ## MATERIAL/METHODS
        for key in ('Extraction Method', 'Label', 'Solvent'):
            for ontokey in ('name', 'accession', 'ref'):
                self.metadata[key][ontokey] = getattr(self.ui, ontokey+'_'+key.lower().replace(' ', '_')).text()
        self.metadata['Sample pH']['value'] = self.ui.value_sample_pH.text()


    def getContactFields(self, contact_type):
        """Unified method to get either Study contact or Investigation contact fields"""

        # empty metadata
        self.metadata[contact_type+'_contacts'] = []

        #either model_contacts or model_contacts_2
        for row_index in range(getattr(self.ui, 'model_contacts'+SUFFIX[contact_type]).rowCount()):
            self.metadata[contact_type+'_contacts'].append(self.getContactByRow(row_index, contact_type))

        #add default if empty
        if not self.metadata[contact_type+'_contacts']:
            self.metadata[contact_type+'_contacts'].append(dict(deepcopy(CONTACT)))

    def getContactByRow(self, row_index, contact_type):
        contact = deepcopy(CONTACT)
        model = getattr(self.ui, 'model_contacts' + SUFFIX[contact_type])
        for (i, key) in enumerate(contact.keys()):
            if key != 'roles':
                contact[key] = model.item(row_index, i).text()
            else:
                contact[key] = {'accession': model.item(row_index, i).text(),
                                'ref': model.item(row_index, i+1).text(),
                                'name': model.item(row_index, i+2).text()
                               }
        return contact

    def addContact(self, contact_type):
        self.contact = ContactDialog(self)
        self.contact.exec_()
        getattr(self.ui, 'model_contacts' + SUFFIX[contact_type]).appendRow(
            [QStandardItem(self.contact.contact[key]) for key in CONTACT.keys() if key != 'roles'] \
            + [QStandardItem(self.contact.contact['roles'][key]) for key in ('accession', 'ref', 'name')]
        )

    def rmContact(self, contact_type):
        indexes = getattr(self.ui, 'table_contacts'+SUFFIX[contact_type]).selectionModel().selection().indexes()
        if indexes is not None:
            row_index = indexes[0].row()
            getattr(self.ui, 'model_contacts'+SUFFIX[contact_type]).removeRow(row_index)

    def editContact(self, contact_type):
        indexes = getattr(self.ui, 'table_contacts'+SUFFIX[contact_type]).selectionModel().selection().indexes()
        if indexes is not None and indexes:
            model = getattr(self.ui, 'model_contacts' + SUFFIX[contact_type])

            row_index = indexes[0].row()
            contact = self.getStudyContactByRow(row_index)

            self.contact = ContactDialog(self, json.dumps(contact))
            self.contact.exec_()

            model.removeRow(row_index)
            model.insertRow(row_index,
                [QStandardItem(self.contact.contact[key]) for key in CONTACT.keys() if key != 'roles'] \
                + [QStandardItem(self.contact.contact['roles'][key]) for key in ('accession', 'ref', 'name')]
            )

    def fillContacts(self, contacts, contact_type):
        model = getattr(self.ui, 'model_contacts' + SUFFIX[contact_type])
        for contact in contacts:
            if contact != CONTACT:
                model.appendRow(
                    [QStandardItem(contact[key]) for key in CONTACT.keys() if key != 'roles'] \
                    + [QStandardItem(contact['roles'][key]) for key in ('accession', 'ref', 'name')]
                )

    def fillPSOComboBoxes(self, jsontology):
        _translate = QCoreApplication.translate
        # Get PSO ontology
        self.ontoPSO = json.loads(jsontology)
        self.ontoPSOk = sorted(self.ontoPSO)
        # Hide status fields (they ARE useful, though !)
        self.ui.status.hide()
        self.ui.status_2.hide()
        # Hide "connecting to PSO" labels
        self.ui.label_pso.hide()
        self.ui.label_pso_2.hide()
        # Add status to combo box
        for i, status in enumerate(self.ontoPSOk):
            self.ui.combo_status.addItem("")
            self.ui.combo_status.setItemText(i, _translate("Dialog", status))
            self.ui.combo_status_2.addItem("")
            self.ui.combo_status_2.setItemText(i, _translate("Dialog", status))
        # Chek if value to display
        if self.metadata['study_publication']['status']['name']:
            self.ui.combo_status.setCurrentText(self.metadata['study_publication']['status']['name'])
            self.ui.status.setText(self.metadata['study_publication']['status']['accession'])
        else:
            self.ui.combo_status.setCurrentIndex(-1)
        if self.metadata['investigation_publication']['status']['name']:
            self.ui.combo_status_2.setCurrentText(self.metadata['investigation_publication']['status']['name'])
            self.ui.status_2.setText(self.metadata['investigation_publication']['status']['accession'])
        else:
            self.ui.combo_status_2.setCurrentIndex(-1)
        # Link comboboxes and display fields
        self.ui.combo_status.activated.connect(lambda x: self.ui.status.setText(\
          self.ontoPSO[self.ui.combo_status.currentText()]))
        self.ui.combo_status_2.activated.connect(lambda x: self.ui.status_2.setText(\
          self.ontoPSO[self.ui.combo_status_2.currentText()]))
        # Enable comboboxes
        self.ui.combo_status.setEnabled(True)
        self.ui.combo_status_2.setEnabled(True)

    def searchCvTerm(self, term):
        """Open an OlsDialog for the right characteristic"""
        self.ols = OlsDialog(self)
        if self.ols.exec_():
            getattr(self.ui, 'name_'+term).setText(self.ols.entry['label'])
            getattr(self.ui, 'ref_'+term).setText(self.ols.entry['ontology_prefix'].upper())
            getattr(self.ui, 'accession_'+term).setText(self.ols.entry['iri'])

    def rmCvTerm(self, term):
        """Empty given characteristic fields."""
        getattr(self.ui, 'name_'+term).setText('')
        getattr(self.ui, 'ref_'+term).setText('')
        getattr(self.ui, 'accession_'+term).setText('')

    def updateSpatialResUnit(self, text):
        self.ui.accession_unit_spatial_resolution.setText(UNIT[text]['accession'])
        self.ui.ref_unit_spatial_resolution.setText(UNIT[text]['ref'])


if __name__=='__main__':

    app = QApplication(sys.argv)
    um = UserMetaDialog()
    um.SigUpdateMetadata.connect(lambda x: print(x))
    um.show()
    sys.exit(app.exec_())



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'qt/progress.ui'
#
# Created by: PyQt5 UI code generator 5.7
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_Dialog(object):
    def setupUi(self, Dialog):
        Dialog.setObjectName("Dialog")
        Dialog.resize(640, 140)
        Dialog.setMinimumSize(QtCore.QSize(640, 140))
        Dialog.setMaximumSize(QtCore.QSize(640, 140))
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(":/graphics/assets/graphics/ebi_icon.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        Dialog.setWindowIcon(icon)
        Dialog.setSizeGripEnabled(False)
        Dialog.setModal(False)
        self.pBar_parse = QtWidgets.QProgressBar(Dialog)
        self.pBar_parse.setGeometry(QtCore.QRect(10, 55, 620, 25))
        palette = QtGui.QPalette()
        brush = QtGui.QBrush(QtGui.QColor(11, 123, 125))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Active, QtGui.QPalette.Highlight, brush)
        brush = QtGui.QBrush(QtGui.QColor(11, 123, 125))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Inactive, QtGui.QPalette.Highlight, brush)
        brush = QtGui.QBrush(QtGui.QColor(209, 209, 209))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Disabled, QtGui.QPalette.Highlight, brush)
        self.pBar_parse.setPalette(palette)
        self.pBar_parse.setStyleSheet("font: 12pt url(:/fonts/assets/fonts/Verdana.ttf);")
        self.pBar_parse.setMaximum(0)
        self.pBar_parse.setProperty("value", 0)
        self.pBar_parse.setAlignment(QtCore.Qt.AlignCenter)
        self.pBar_parse.setObjectName("pBar_parse")
        self.pBar_studies = QtWidgets.QProgressBar(Dialog)
        self.pBar_studies.setGeometry(QtCore.QRect(10, 20, 620, 25))
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pBar_studies.sizePolicy().hasHeightForWidth())
        self.pBar_studies.setSizePolicy(sizePolicy)
        self.pBar_studies.setSizeIncrement(QtCore.QSize(0, 0))
        self.pBar_studies.setStyleSheet("font: 12pt url(:/fonts/assets/fonts/Verdana.ttf);")
        self.pBar_studies.setMaximum(0)
        self.pBar_studies.setProperty("value", 0)
        self.pBar_studies.setAlignment(QtCore.Qt.AlignCenter)
        self.pBar_studies.setObjectName("pBar_studies")
        self.label_study = QtWidgets.QLabel(Dialog)
        self.label_study.setGeometry(QtCore.QRect(10, 20, 620, 25))
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_study.sizePolicy().hasHeightForWidth())
        self.label_study.setSizePolicy(sizePolicy)
        palette = QtGui.QPalette()
        brush = QtGui.QBrush(QtGui.QColor(11, 122, 124))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Active, QtGui.QPalette.Highlight, brush)
        brush = QtGui.QBrush(QtGui.QColor(11, 122, 124))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Inactive, QtGui.QPalette.Highlight, brush)
        brush = QtGui.QBrush(QtGui.QColor(209, 209, 209))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Disabled, QtGui.QPalette.Highlight, brush)
        self.label_study.setPalette(palette)
        self.label_study.setAutoFillBackground(False)
        self.label_study.setStyleSheet("font: 12pt url(:/fonts/assets/fonts/Verdana.ttf);")
        self.label_study.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.label_study.setObjectName("label_study")
        self.textEdit_filename = QtWidgets.QTextEdit(Dialog)
        self.textEdit_filename.setGeometry(QtCore.QRect(9, 95, 620, 25))
        font = QtGui.QFont()
        font.setFamily("Monospace")
        font.setPointSize(10)
        font.setBold(False)
        font.setItalic(False)
        font.setWeight(50)
        self.textEdit_filename.setFont(font)
        self.textEdit_filename.setStyleSheet("background-color: rgb(0, 0, 0);\n"
"font: 10pt \"Monospace\";\n"
"color: rgb(255,255,255);")
        self.textEdit_filename.setTextInteractionFlags(QtCore.Qt.NoTextInteraction)
        self.textEdit_filename.setObjectName("textEdit_filename")

        self.retranslateUi(Dialog)
        QtCore.QMetaObject.connectSlotsByName(Dialog)

    def retranslateUi(self, Dialog):
        _translate = QtCore.QCoreApplication.translate
        Dialog.setWindowTitle(_translate("Dialog", "Dialog"))
        self.pBar_parse.setFormat(_translate("Dialog", "%v / %m files parsed"))
        self.pBar_studies.setFormat(_translate("Dialog", "%v / %m studies parsed"))
        self.label_study.setText(_translate("Dialog", "TextLabel"))

import resources_rc



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'qt/contact.ui'
#
# Created by: PyQt5 UI code generator 5.7
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_Dialog(object):
    def setupUi(self, Dialog):
        Dialog.setObjectName("Dialog")
        Dialog.resize(450, 320)
        self.buttonBox = QtWidgets.QDialogButtonBox(Dialog)
        self.buttonBox.setGeometry(QtCore.QRect(250, 270, 181, 51))
        self.buttonBox.setOrientation(QtCore.Qt.Horizontal)
        self.buttonBox.setStandardButtons(QtWidgets.QDialogButtonBox.Cancel|QtWidgets.QDialogButtonBox.Ok)
        self.buttonBox.setObjectName("buttonBox")
        self.label_20 = QtWidgets.QLabel(Dialog)
        self.label_20.setGeometry(QtCore.QRect(20, 220, 131, 25))
        self.label_20.setObjectName("label_20")
        self.label_15 = QtWidgets.QLabel(Dialog)
        self.label_15.setGeometry(QtCore.QRect(150, 20, 71, 16))
        self.label_15.setScaledContents(False)
        self.label_15.setWordWrap(True)
        self.label_15.setObjectName("label_15")
        self.label_18 = QtWidgets.QLabel(Dialog)
        self.label_18.setGeometry(QtCore.QRect(20, 120, 131, 25))
        self.label_18.setObjectName("label_18")
        self.last_name = QtWidgets.QLineEdit(Dialog)
        self.last_name.setGeometry(QtCore.QRect(235, 40, 195, 25))
        self.last_name.setObjectName("last_name")
        self.roles = QtWidgets.QLineEdit(Dialog)
        self.roles.setEnabled(True)
        self.roles.setGeometry(QtCore.QRect(20, 240, 195, 25))
        self.roles.setStyleSheet("color: rgb(0, 0, 0);")
        self.roles.setFrame(False)
        self.roles.setObjectName("roles")
        self.label_21 = QtWidgets.QLabel(Dialog)
        self.label_21.setGeometry(QtCore.QRect(235, 120, 131, 25))
        self.label_21.setObjectName("label_21")
        self.label_16 = QtWidgets.QLabel(Dialog)
        self.label_16.setGeometry(QtCore.QRect(20, 70, 131, 25))
        self.label_16.setObjectName("label_16")
        self.label_13 = QtWidgets.QLabel(Dialog)
        self.label_13.setGeometry(QtCore.QRect(20, 20, 131, 16))
        self.label_13.setObjectName("label_13")
        self.first_name = QtWidgets.QLineEdit(Dialog)
        self.first_name.setGeometry(QtCore.QRect(20, 40, 130, 25))
        self.first_name.setObjectName("first_name")
        self.adress = QtWidgets.QPlainTextEdit(Dialog)
        self.adress.setGeometry(QtCore.QRect(235, 139, 195, 131))
        self.adress.setObjectName("adress")
        self.email = QtWidgets.QLineEdit(Dialog)
        self.email.setGeometry(QtCore.QRect(235, 90, 195, 25))
        self.email.setInputMethodHints(QtCore.Qt.ImhEmailCharactersOnly)
        self.email.setObjectName("email")
        self.label_17 = QtWidgets.QLabel(Dialog)
        self.label_17.setGeometry(QtCore.QRect(235, 70, 131, 25))
        self.label_17.setObjectName("label_17")
        self.affiliation = QtWidgets.QLineEdit(Dialog)
        self.affiliation.setGeometry(QtCore.QRect(20, 190, 195, 25))
        self.affiliation.setObjectName("affiliation")
        self.fax = QtWidgets.QLineEdit(Dialog)
        self.fax.setGeometry(QtCore.QRect(20, 140, 195, 25))
        self.fax.setInputMethodHints(QtCore.Qt.ImhDialableCharactersOnly)
        self.fax.setObjectName("fax")
        self.combo_roles = QtWidgets.QComboBox(Dialog)
        self.combo_roles.setEnabled(False)
        self.combo_roles.setGeometry(QtCore.QRect(20, 240, 195, 25))
        self.combo_roles.setObjectName("combo_roles")
        self.label_pro = QtWidgets.QLabel(Dialog)
        self.label_pro.setGeometry(QtCore.QRect(30, 240, 241, 25))
        self.label_pro.setWordWrap(True)
        self.label_pro.setObjectName("label_pro")
        self.mid = QtWidgets.QLineEdit(Dialog)
        self.mid.setGeometry(QtCore.QRect(170, 40, 45, 25))
        self.mid.setObjectName("mid")
        self.label_14 = QtWidgets.QLabel(Dialog)
        self.label_14.setGeometry(QtCore.QRect(235, 20, 131, 16))
        self.label_14.setObjectName("label_14")
        self.label_23 = QtWidgets.QLabel(Dialog)
        self.label_23.setGeometry(QtCore.QRect(20, 170, 131, 25))
        self.label_23.setObjectName("label_23")
        self.phone = QtWidgets.QLineEdit(Dialog)
        self.phone.setGeometry(QtCore.QRect(20, 90, 195, 25))
        self.phone.setInputMethodHints(QtCore.Qt.ImhDialableCharactersOnly)
        self.phone.setObjectName("phone")

        self.retranslateUi(Dialog)
        self.buttonBox.accepted.connect(Dialog.accept)
        self.buttonBox.rejected.connect(Dialog.reject)
        QtCore.QMetaObject.connectSlotsByName(Dialog)
        Dialog.setTabOrder(self.first_name, self.mid)
        Dialog.setTabOrder(self.mid, self.last_name)
        Dialog.setTabOrder(self.last_name, self.phone)
        Dialog.setTabOrder(self.phone, self.email)
        Dialog.setTabOrder(self.email, self.fax)
        Dialog.setTabOrder(self.fax, self.affiliation)
        Dialog.setTabOrder(self.affiliation, self.combo_roles)
        Dialog.setTabOrder(self.combo_roles, self.adress)
        Dialog.setTabOrder(self.adress, self.roles)

    def retranslateUi(self, Dialog):
        _translate = QtCore.QCoreApplication.translate
        Dialog.setWindowTitle(_translate("Dialog", "Contact"))
        self.label_20.setText(_translate("Dialog", "Role"))
        self.label_15.setText(_translate("Dialog", "Mid Initials"))
        self.label_18.setText(_translate("Dialog", "Fax"))
        self.label_21.setText(_translate("Dialog", "Adress"))
        self.label_16.setText(_translate("Dialog", "Telephone"))
        self.label_13.setText(_translate("Dialog", "First Name"))
        self.label_17.setText(_translate("Dialog", "Mail"))
        self.label_pro.setText(_translate("Dialog", "connecting to PRO <...>"))
        self.label_14.setText(_translate("Dialog", "Last Name"))
        self.label_23.setText(_translate("Dialog", "Affiliation"))




#!/usr/bin/env python3

## BACKEND
import sys
import os
import json

## FRONTEND
from PyQt5.QtWidgets import * #QApplication, QMainWindow
from PyQt5.QtCore import *
from PyQt5.QtGui import QPalette, QStandardItemModel, QStandardItem

## UI
from nmrml2isa_qt.qt.ols import Ui_Dialog as Ui_Ols

## UI MODULES
from nmrml2isa_qt.scrapers import OlsOntologist, OlsSearcher, OlsExplorer



class OlsDialog(QDialog):
    """Dialog to search the OLS for an ontology

    The OlsDialog uses threads to connect to the Ontology Lookup Service,
    and search for a query, get results, and get informations about
    ontologies.

    Selected ontology is returned as a json serialized dict.
    """

    SigSearchCompleted = pyqtSignal('QString')

    def __init__(self, parent=None, allow_onto=False):
        super(OlsDialog, self).__init__(parent)

        self.ui = Ui_Ols()
        self.ui.setupUi(self)
        self.ui.buttonBox.button(QDialogButtonBox.Ok).setEnabled(False)

        self.onto = {}
        self.ontothreads = {}
        self.allow_onto = allow_onto
        self.entry = None

        self.ui.buttonBox.button(QDialogButtonBox.Ok).clicked.connect(self.accept)
        self.ui.buttonBox.button(QDialogButtonBox.Cancel).clicked.connect(self.reject)

        self.ui.searchButton.clicked.connect(self.search)
        self.ui.queryLine.setFocus()

    def search(self):
        """Launch the OlsSearchThread"""
        self.searcher = OlsSearcher(self.ui.queryLine.text())
        self.searcher.Finished.connect(self.updateSearchResults)
        self.searcher.start()

    def updateSearchResults(self, jresults):
        """Update TreeView with search results."""

        self.model = QStandardItemModel()
        self.orderedResults = {}

        if jresults:

            self.results = json.loads(jresults)

            for result in self.results:
                prefix = result['ontology_prefix']

                # Create a new node & append it to StandardItemModel
                # if the ontology of the result is not already in StandardItemModel
                if not self.model.findItems(prefix):
                    node = QStandardItem(prefix)
                    self.model.appendRow(node)

                # Look for details of that new ontology if that ontology is not
                # already memo table and not other OlsOntologist is querying
                # informations about that ontology
                if prefix not in self.ontothreads and prefix not in self.onto:
                    thread = OlsOntologist(prefix)
                    thread.Finished.connect(self._memo_onto)
                    thread.start()
                    self.ontothreads[prefix] = thread

                # Add the entry to its ontology node
                result['tag'] = result['short_form'].replace('_', ':') + ' - ' + result['label']
                self.model.findItems(prefix)[0].appendRow(
                        QStandardItem(result['tag'])
                    )

        self.model.sort(0)
        self.ui.ontoTree.setModel(self.model)
        #self.ui.ontoTree.expandAll()
        self.model.setHorizontalHeaderLabels(["Object"])
        self.ui.ontoTree.selectionModel().selectionChanged.connect(
            lambda selection: self.updateInterface(selection.indexes()[0])
            )
        self.ui.ontoTree.clicked.connect(self.updateInterface)
        self.ui.ontoTree.doubleClicked.connect(self.onDoubleClick)

    def _getResultFromIndex(self, index):
        """Iterate on self.results to get the right entry"""
        crawler = self.model.itemFromIndex(index)
        self.entry = None
        for x in self.results:
            if x['tag'] == crawler.text():
                self.entry = x
        return crawler.text()

    def updateInterface(self, index):
        """Update the interface fields with the value from the TreeView"""

        if index:
            tag = self._getResultFromIndex(index)

            # selection is an ontology
            if self.entry is None:

                if not self.allow_onto:
                    self.ui.buttonBox.button(QDialogButtonBox.Ok).setEnabled(False)

                # information about ontology is present in memoization table
                if tag in self.onto.keys():

                    self.entry = self.onto[tag]
                    self.ui.value.setPlainText(self.entry['title'])
                    self.ui.prefix.setText(self.entry['preferredPrefix'])
                    self.ui.iri.setPlainText(self.entry['id'])
                    self.ui.description.setPlainText(self.entry['description'])

                # No information is to be found
                else:
                    self.ui.value.setPlainText("")
                    self.ui.prefix.setText("")
                    self.ui.iri.setPlainText("")
                    self.ui.description.setPlainText("")

                self.ui.prefix.setText(tag)
                self.ui.type.setText('Ontology')

            # selection is a class
            else:

                self.ui.buttonBox.button(QDialogButtonBox.Ok).setEnabled(True)

                self.ui.value.setPlainText(self.entry['label'])
                self.ui.prefix.setText(self.entry['ontology_prefix'])
                self.ui.iri.setPlainText(self.entry['iri'])
                self.ui.type.setText('Class')

                self.ui.description.setPlainText(
                    self.entry['description'][0] if 'description' in self.entry else ''
                    )

    def onDoubleClick(self, index):
        """Return class when double clicked"""
        self._getResultFromIndex(index)
        if self.entry is not None:
            self.accept()

    def _memo_onto(self, prefix, jsonconfig):
        self.onto[prefix] = json.loads(jsonconfig)

if __name__=='__main__':
    app = QApplication(sys.argv)
    ols = OlsDialog()
    ols.exec_()
    print(ols.entry)





# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'qt/main.ui'
#
# Created by: PyQt5 UI code generator 5.7
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        MainWindow.setObjectName("MainWindow")
        MainWindow.resize(640, 480)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(MainWindow.sizePolicy().hasHeightForWidth())
        MainWindow.setSizePolicy(sizePolicy)
        MainWindow.setMinimumSize(QtCore.QSize(640, 480))
        MainWindow.setMaximumSize(QtCore.QSize(640, 480))
        MainWindow.setContextMenuPolicy(QtCore.Qt.DefaultContextMenu)
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(":/graphics/assets/graphics/ebi_icon.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        MainWindow.setWindowIcon(icon)
        MainWindow.setStyleSheet("")
        self.centralwidget = QtWidgets.QWidget(MainWindow)
        self.centralwidget.setObjectName("centralwidget")
        self.lineEdit_input = QtWidgets.QLineEdit(self.centralwidget)
        self.lineEdit_input.setEnabled(True)
        self.lineEdit_input.setGeometry(QtCore.QRect(10, 140, 620, 22))
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lineEdit_input.sizePolicy().hasHeightForWidth())
        self.lineEdit_input.setSizePolicy(sizePolicy)
        self.lineEdit_input.setStyleSheet("font: 10pt url(:/fonts/assets/fonts/Verdana.ttf);")
        self.lineEdit_input.setLocale(QtCore.QLocale(QtCore.QLocale.French, QtCore.QLocale.France))
        self.lineEdit_input.setObjectName("lineEdit_input")
        self.lbl_input = QtWidgets.QLabel(self.centralwidget)
        self.lbl_input.setGeometry(QtCore.QRect(20, 162, 180, 18))
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lbl_input.sizePolicy().hasHeightForWidth())
        self.lbl_input.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setFamily(":/fonts/assets/fonts/Verdana.ttf")
        font.setPointSize(10)
        font.setBold(False)
        font.setItalic(False)
        font.setWeight(50)
        self.lbl_input.setFont(font)
        self.lbl_input.setStyleSheet("font: 10pt url(:/fonts/assets/fonts/Verdana.ttf);")
        self.lbl_input.setObjectName("lbl_input")
        self.lineEdit_output = QtWidgets.QLineEdit(self.centralwidget)
        self.lineEdit_output.setEnabled(False)
        self.lineEdit_output.setGeometry(QtCore.QRect(10, 200, 620, 22))
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lineEdit_output.sizePolicy().hasHeightForWidth())
        self.lineEdit_output.setSizePolicy(sizePolicy)
        self.lineEdit_output.setStyleSheet("font: 10pt url(:/fonts/assets/fonts/Verdana.ttf);")
        self.lineEdit_output.setText("")
        self.lineEdit_output.setObjectName("lineEdit_output")
        self.lineEdit_study = QtWidgets.QLineEdit(self.centralwidget)
        self.lineEdit_study.setEnabled(False)
        self.lineEdit_study.setGeometry(QtCore.QRect(10, 260, 620, 22))
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lineEdit_study.sizePolicy().hasHeightForWidth())
        self.lineEdit_study.setSizePolicy(sizePolicy)
        self.lineEdit_study.setStyleSheet("font: 10pt url(:/fonts/assets/fonts/Verdana.ttf);")
        self.lineEdit_study.setObjectName("lineEdit_study")
        self.lbl_output = QtWidgets.QLabel(self.centralwidget)
        self.lbl_output.setGeometry(QtCore.QRect(20, 222, 180, 18))
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lbl_output.sizePolicy().hasHeightForWidth())
        self.lbl_output.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setFamily(":/fonts/assets/fonts/Verdana.ttf")
        font.setPointSize(10)
        font.setBold(False)
        font.setItalic(False)
        font.setWeight(50)
        self.lbl_output.setFont(font)
        self.lbl_output.setStyleSheet("font: 10pt url(:/fonts/assets/fonts/Verdana.ttf);")
        self.lbl_output.setObjectName("lbl_output")
        self.lbl_study = QtWidgets.QLabel(self.centralwidget)
        self.lbl_study.setGeometry(QtCore.QRect(20, 282, 180, 18))
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lbl_study.sizePolicy().hasHeightForWidth())
        self.lbl_study.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setFamily(":/fonts/assets/fonts/Verdana.ttf")
        font.setPointSize(10)
        font.setBold(False)
        font.setItalic(False)
        font.setWeight(50)
        self.lbl_study.setFont(font)
        self.lbl_study.setStyleSheet("font: 10pt url(:/fonts/assets/fonts/Verdana.ttf);")
        self.lbl_study.setObjectName("lbl_study")
        self.toolButton_input_explore = QtWidgets.QToolButton(self.centralwidget)
        self.toolButton_input_explore.setGeometry(QtCore.QRect(530, 162, 90, 25))
        self.toolButton_input_explore.setStyleSheet("font: 10pt url(:/fonts/assets/fonts/Verdana.ttf);")
        icon1 = QtGui.QIcon()
        icon1.addPixmap(QtGui.QPixmap("assets/graphics/browse_icon.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.toolButton_input_explore.setIcon(icon1)
        self.toolButton_input_explore.setIconSize(QtCore.QSize(16, 16))
        self.toolButton_input_explore.setToolButtonStyle(QtCore.Qt.ToolButtonTextOnly)
        self.toolButton_input_explore.setAutoRaise(False)
        self.toolButton_input_explore.setArrowType(QtCore.Qt.NoArrow)
        self.toolButton_input_explore.setObjectName("toolButton_input_explore")
        self.toolButton_output_explore = QtWidgets.QToolButton(self.centralwidget)
        self.toolButton_output_explore.setEnabled(False)
        self.toolButton_output_explore.setGeometry(QtCore.QRect(530, 222, 90, 25))
        self.toolButton_output_explore.setStyleSheet("font: 10pt url(:/fonts/assets/fonts/Verdana.ttf);")
        icon2 = QtGui.QIcon()
        icon2.addPixmap(QtGui.QPixmap(":/graphics/assets/graphics/browse_icon.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.toolButton_output_explore.setIcon(icon2)
        self.toolButton_output_explore.setIconSize(QtCore.QSize(16, 16))
        self.toolButton_output_explore.setToolButtonStyle(QtCore.Qt.ToolButtonTextOnly)
        self.toolButton_output_explore.setObjectName("toolButton_output_explore")
        self.cBox_multiple = QtWidgets.QCheckBox(self.centralwidget)
        self.cBox_multiple.setGeometry(QtCore.QRect(10, 380, 280, 22))
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.cBox_multiple.sizePolicy().hasHeightForWidth())
        self.cBox_multiple.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setFamily(":/fonts/assets/fonts/Verdana.ttf")
        font.setPointSize(10)
        font.setBold(False)
        font.setItalic(False)
        font.setWeight(50)
        self.cBox_multiple.setFont(font)
        self.cBox_multiple.setStyleSheet("font: 10pt url(:/fonts/assets/fonts/Verdana.ttf);")
        self.cBox_multiple.setObjectName("cBox_multiple")
        self.cBox_export = QtWidgets.QCheckBox(self.centralwidget)
        self.cBox_export.setGeometry(QtCore.QRect(10, 400, 340, 22))
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.cBox_export.sizePolicy().hasHeightForWidth())
        self.cBox_export.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setFamily(":/fonts/assets/fonts/Verdana.ttf")
        font.setPointSize(10)
        font.setBold(False)
        font.setItalic(False)
        font.setWeight(50)
        self.cBox_export.setFont(font)
        self.cBox_export.setStyleSheet("font: 10pt url(:/fonts/assets/fonts/Verdana.ttf);")
        self.cBox_export.setChecked(True)
        self.cBox_export.setObjectName("cBox_export")
        self.PushBut_convert = QtWidgets.QPushButton(self.centralwidget)
        self.PushBut_convert.setGeometry(QtCore.QRect(530, 370, 90, 51))
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.PushBut_convert.sizePolicy().hasHeightForWidth())
        self.PushBut_convert.setSizePolicy(sizePolicy)
        self.PushBut_convert.setStyleSheet("font: 10pt url(:/fonts/assets/fonts/Verdana.ttf);")
        self.PushBut_convert.setObjectName("PushBut_convert")
        self.toolButton_help = QtWidgets.QToolButton(self.centralwidget)
        self.toolButton_help.setGeometry(QtCore.QRect(330, 370, 90, 25))
        self.toolButton_help.setStyleSheet("font: 10pt url(:/fonts/assets/fonts/Verdana.ttf);")
        self.toolButton_help.setObjectName("toolButton_help")
        self.lbl_input_error = QtWidgets.QLabel(self.centralwidget)
        self.lbl_input_error.setGeometry(QtCore.QRect(150, 162, 370, 18))
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lbl_input_error.sizePolicy().hasHeightForWidth())
        self.lbl_input_error.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setFamily(":/fonts/assets/fonts/Verdana.ttf")
        font.setPointSize(10)
        font.setBold(False)
        font.setItalic(False)
        font.setWeight(50)
        self.lbl_input_error.setFont(font)
        self.lbl_input_error.setStyleSheet("color: rgb(216, 1, 35);\n"
"font: 10pt url(:/fonts/assets/fonts/Verdana.ttf);")
        self.lbl_input_error.setText("")
        self.lbl_input_error.setObjectName("lbl_input_error")
        self.lbl_output_error = QtWidgets.QLabel(self.centralwidget)
        self.lbl_output_error.setGeometry(QtCore.QRect(150, 222, 370, 18))
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lbl_output_error.sizePolicy().hasHeightForWidth())
        self.lbl_output_error.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setFamily(":/fonts/assets/fonts/Verdana.ttf")
        font.setPointSize(10)
        font.setBold(False)
        font.setItalic(False)
        font.setWeight(50)
        self.lbl_output_error.setFont(font)
        self.lbl_output_error.setStyleSheet("color: rgb(216, 1, 35);\n"
"font: 10pt url(:/fonts/assets/fonts/Verdana.ttf);")
        self.lbl_output_error.setText("")
        self.lbl_output_error.setObjectName("lbl_output_error")
        self.lbl_study_error = QtWidgets.QLabel(self.centralwidget)
        self.lbl_study_error.setGeometry(QtCore.QRect(150, 282, 370, 18))
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lbl_study_error.sizePolicy().hasHeightForWidth())
        self.lbl_study_error.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setFamily(":/fonts/assets/fonts/Verdana.ttf")
        font.setPointSize(10)
        font.setBold(False)
        font.setItalic(False)
        font.setWeight(50)
        self.lbl_study_error.setFont(font)
        self.lbl_study_error.setStyleSheet("color: rgb(216, 1, 35);\n"
"font: 10pt url(:/fonts/assets/fonts/Verdana.ttf);")
        self.lbl_study_error.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.lbl_study_error.setText("")
        self.lbl_study_error.setTextFormat(QtCore.Qt.AutoText)
        self.lbl_study_error.setTextInteractionFlags(QtCore.Qt.NoTextInteraction)
        self.lbl_study_error.setObjectName("lbl_study_error")
        self.frame = QtWidgets.QFrame(self.centralwidget)
        self.frame.setGeometry(QtCore.QRect(0, 0, 640, 62))
        self.frame.setStyleSheet("background: rgb(11, 123, 189);\n"
"")
        self.frame.setFrameShape(QtWidgets.QFrame.Box)
        self.frame.setFrameShadow(QtWidgets.QFrame.Plain)
        self.frame.setObjectName("frame")
        self.logo = QtWidgets.QLabel(self.frame)
        self.logo.setGeometry(QtCore.QRect(1, 1, 240, 60))
        self.logo.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.logo.setText("")
        self.logo.setPixmap(QtGui.QPixmap(":/graphics/assets/graphics/ebi-logo.jpg"))
        self.logo.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.logo.setObjectName("logo")
        self.title = QtWidgets.QLabel(self.frame)
        self.title.setGeometry(QtCore.QRect(349, 1, 291, 62))
        font = QtGui.QFont()
        font.setFamily(":/fonts/assets/fonts/HelveticaNeue.ttf")
        font.setPointSize(24)
        font.setBold(False)
        font.setItalic(False)
        font.setWeight(50)
        self.title.setFont(font)
        self.title.setStyleSheet("color: rgb(255,255,255);\n"
"font: 24pt url(:/fonts/assets/fonts/HelveticaNeue.ttf);")
        self.title.setObjectName("title")
        self.toolButton_metadata = QtWidgets.QToolButton(self.centralwidget)
        self.toolButton_metadata.setEnabled(True)
        self.toolButton_metadata.setGeometry(QtCore.QRect(430, 370, 90, 51))
        self.toolButton_metadata.setCheckable(False)
        self.toolButton_metadata.setAutoRepeatInterval(100)
        self.toolButton_metadata.setPopupMode(QtWidgets.QToolButton.DelayedPopup)
        self.toolButton_metadata.setAutoRaise(False)
        self.toolButton_metadata.setObjectName("toolButton_metadata")
        self.toolButton_about = QtWidgets.QToolButton(self.centralwidget)
        self.toolButton_about.setGeometry(QtCore.QRect(330, 395, 90, 25))
        self.toolButton_about.setStyleSheet("font: 10pt url(:/fonts/assets/fonts/Verdana.ttf);")
        self.toolButton_about.setObjectName("toolButton_about")
        MainWindow.setCentralWidget(self.centralwidget)
        self.menubar = QtWidgets.QMenuBar(MainWindow)
        self.menubar.setEnabled(False)
        self.menubar.setGeometry(QtCore.QRect(0, 0, 640, 23))
        self.menubar.setNativeMenuBar(True)
        self.menubar.setObjectName("menubar")
        MainWindow.setMenuBar(self.menubar)
        self.statusbar = QtWidgets.QStatusBar(MainWindow)
        self.statusbar.setObjectName("statusbar")
        MainWindow.setStatusBar(self.statusbar)

        self.retranslateUi(MainWindow)
        QtCore.QMetaObject.connectSlotsByName(MainWindow)

    def retranslateUi(self, MainWindow):
        _translate = QtCore.QCoreApplication.translate
        MainWindow.setWindowTitle(_translate("MainWindow", "nmrML to ISA-Tab"))
        self.lbl_input.setText(_translate("MainWindow", "Input folder"))
        self.lbl_output.setText(_translate("MainWindow", "Output folder"))
        self.lbl_study.setText(_translate("MainWindow", "Study name"))
        self.toolButton_input_explore.setText(_translate("MainWindow", "Browse"))
        self.toolButton_output_explore.setText(_translate("MainWindow", "Browse"))
        self.cBox_multiple.setText(_translate("MainWindow", "Input folder contains several studies"))
        self.cBox_export.setText(_translate("MainWindow", "Export results to directory of each study"))
        self.PushBut_convert.setText(_translate("MainWindow", "Convert"))
        self.toolButton_help.setText(_translate("MainWindow", "Help"))
        self.title.setText(_translate("MainWindow", "nmrML to ISA-Tab "))
        self.toolButton_metadata.setText(_translate("MainWindow", "Add \n"
"Metadata"))
        self.toolButton_about.setText(_translate("MainWindow", "About"))

import resources_rc



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'qt/usermeta.ui'
#
# Created by: PyQt5 UI code generator 5.7
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_Dialog(object):
    def setupUi(self, Dialog):
        Dialog.setObjectName("Dialog")
        Dialog.resize(960, 640)
        Dialog.setMinimumSize(QtCore.QSize(960, 640))
        Dialog.setMaximumSize(QtCore.QSize(960, 640))
        self.tabWidget = QtWidgets.QTabWidget(Dialog)
        self.tabWidget.setGeometry(QtCore.QRect(30, 40, 900, 550))
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.tabWidget.sizePolicy().hasHeightForWidth())
        self.tabWidget.setSizePolicy(sizePolicy)
        self.tabWidget.setTabShape(QtWidgets.QTabWidget.Rounded)
        self.tabWidget.setUsesScrollButtons(True)
        self.tabWidget.setDocumentMode(False)
        self.tabWidget.setTabsClosable(False)
        self.tabWidget.setMovable(False)
        self.tabWidget.setObjectName("tabWidget")
        self.tab_study = QtWidgets.QWidget()
        self.tab_study.setObjectName("tab_study")
        self.identifier = QtWidgets.QLineEdit(self.tab_study)
        self.identifier.setEnabled(False)
        self.identifier.setGeometry(QtCore.QRect(20, 70, 420, 25))
        self.identifier.setStyleSheet("font: italic 10pt url(:/fonts/assets/fonts/Verdana.ttf);")
        self.identifier.setText("")
        self.identifier.setObjectName("identifier")
        self.title = QtWidgets.QLineEdit(self.tab_study)
        self.title.setGeometry(QtCore.QRect(20, 120, 420, 25))
        self.title.setText("")
        self.title.setObjectName("title")
        self.label = QtWidgets.QLabel(self.tab_study)
        self.label.setEnabled(False)
        self.label.setGeometry(QtCore.QRect(20, 50, 131, 16))
        self.label.setObjectName("label")
        self.label_2 = QtWidgets.QLabel(self.tab_study)
        self.label_2.setGeometry(QtCore.QRect(20, 100, 131, 16))
        self.label_2.setObjectName("label_2")
        self.label_3 = QtWidgets.QLabel(self.tab_study)
        self.label_3.setGeometry(QtCore.QRect(20, 150, 131, 16))
        self.label_3.setObjectName("label_3")
        self.submission_date = QtWidgets.QDateEdit(self.tab_study)
        self.submission_date.setGeometry(QtCore.QRect(20, 170, 201, 25))
        self.submission_date.setCalendarPopup(False)
        self.submission_date.setObjectName("submission_date")
        self.label_4 = QtWidgets.QLabel(self.tab_study)
        self.label_4.setGeometry(QtCore.QRect(250, 150, 131, 16))
        self.label_4.setObjectName("label_4")
        self.release_date = QtWidgets.QDateEdit(self.tab_study)
        self.release_date.setGeometry(QtCore.QRect(239, 170, 201, 25))
        self.release_date.setProperty("showGroupSeparator", False)
        self.release_date.setCalendarPopup(False)
        self.release_date.setDate(QtCore.QDate(2000, 1, 1))
        self.release_date.setObjectName("release_date")
        self.label_5 = QtWidgets.QLabel(self.tab_study)
        self.label_5.setGeometry(QtCore.QRect(20, 20, 261, 31))
        self.label_5.setStyleSheet("font: 12pt url(:/fonts/assets/fonts/Verdana.ttf);")
        self.label_5.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignTop)
        self.label_5.setObjectName("label_5")
        self.label_6 = QtWidgets.QLabel(self.tab_study)
        self.label_6.setGeometry(QtCore.QRect(20, 230, 261, 31))
        self.label_6.setStyleSheet("font: 12pt url(:/fonts/assets/fonts/Verdana.ttf);")
        self.label_6.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignTop)
        self.label_6.setObjectName("label_6")
        self.pubmed_id = QtWidgets.QLineEdit(self.tab_study)
        self.pubmed_id.setGeometry(QtCore.QRect(20, 280, 131, 25))
        self.pubmed_id.setInputMethodHints(QtCore.Qt.ImhDigitsOnly)
        self.pubmed_id.setObjectName("pubmed_id")
        self.label_7 = QtWidgets.QLabel(self.tab_study)
        self.label_7.setGeometry(QtCore.QRect(20, 260, 131, 16))
        self.label_7.setObjectName("label_7")
        self.doi = QtWidgets.QLineEdit(self.tab_study)
        self.doi.setGeometry(QtCore.QRect(169, 280, 271, 25))
        self.doi.setObjectName("doi")
        self.label_8 = QtWidgets.QLabel(self.tab_study)
        self.label_8.setGeometry(QtCore.QRect(170, 260, 131, 16))
        self.label_8.setObjectName("label_8")
        self.pub_title = QtWidgets.QLineEdit(self.tab_study)
        self.pub_title.setGeometry(QtCore.QRect(20, 330, 420, 25))
        self.pub_title.setText("")
        self.pub_title.setObjectName("pub_title")
        self.label_9 = QtWidgets.QLabel(self.tab_study)
        self.label_9.setGeometry(QtCore.QRect(20, 310, 131, 16))
        self.label_9.setObjectName("label_9")
        self.combo_status = QtWidgets.QComboBox(self.tab_study)
        self.combo_status.setEnabled(False)
        self.combo_status.setGeometry(QtCore.QRect(20, 380, 421, 25))
        self.combo_status.setCurrentText("")
        self.combo_status.setObjectName("combo_status")
        self.label_10 = QtWidgets.QLabel(self.tab_study)
        self.label_10.setGeometry(QtCore.QRect(20, 360, 131, 16))
        self.label_10.setObjectName("label_10")
        self.label_11 = QtWidgets.QLabel(self.tab_study)
        self.label_11.setGeometry(QtCore.QRect(470, 50, 211, 16))
        self.label_11.setObjectName("label_11")
        self.label_12 = QtWidgets.QLabel(self.tab_study)
        self.label_12.setGeometry(QtCore.QRect(470, 230, 261, 31))
        self.label_12.setStyleSheet("font: 12pt url(:/fonts/assets/fonts/Verdana.ttf);")
        self.label_12.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignTop)
        self.label_12.setObjectName("label_12")
        self.line = QtWidgets.QFrame(self.tab_study)
        self.line.setGeometry(QtCore.QRect(445, 260, 20, 241))
        self.line.setFrameShape(QtWidgets.QFrame.VLine)
        self.line.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line.setObjectName("line")
        self.label_51 = QtWidgets.QLabel(self.tab_study)
        self.label_51.setGeometry(QtCore.QRect(20, 410, 131, 16))
        self.label_51.setObjectName("label_51")
        self.authors_list = QtWidgets.QTextEdit(self.tab_study)
        self.authors_list.setGeometry(QtCore.QRect(20, 430, 421, 81))
        self.authors_list.setObjectName("authors_list")
        self.status = QtWidgets.QLineEdit(self.tab_study)
        self.status.setGeometry(QtCore.QRect(20, 370, 421, 41))
        self.status.setFrame(False)
        self.status.setObjectName("status")
        self.label_pso = QtWidgets.QLabel(self.tab_study)
        self.label_pso.setGeometry(QtCore.QRect(30, 380, 401, 25))
        self.label_pso.setObjectName("label_pso")
        self.description = QtWidgets.QPlainTextEdit(self.tab_study)
        self.description.setGeometry(QtCore.QRect(470, 70, 401, 121))
        self.description.setObjectName("description")
        self.rm_contact = QtWidgets.QPushButton(self.tab_study)
        self.rm_contact.setGeometry(QtCore.QRect(840, 250, 31, 20))
        self.rm_contact.setStyleSheet("font: 9pt url(:/fonts/assets/fonts/EBI-Functional.ttf);\n"
"font-family: \"EBI-Functional\";")
        self.rm_contact.setObjectName("rm_contact")
        self.add_contact = QtWidgets.QPushButton(self.tab_study)
        self.add_contact.setGeometry(QtCore.QRect(800, 250, 31, 21))
        self.add_contact.setStyleSheet("font: 9pt url(:/fonts/assets/fonts/EBI-Functional.ttf);\n"
"font-family: \"EBI-Functional\";")
        self.add_contact.setObjectName("add_contact")
        self.edit_contact = QtWidgets.QPushButton(self.tab_study)
        self.edit_contact.setGeometry(QtCore.QRect(760, 250, 31, 20))
        self.edit_contact.setStyleSheet("font: 9pt url(:/fonts/assets/fonts/EBI-Functional.ttf);\n"
"font-family: \"EBI-Functional\";")
        self.edit_contact.setObjectName("edit_contact")
        self.table_contacts = QtWidgets.QTableView(self.tab_study)
        self.table_contacts.setGeometry(QtCore.QRect(470, 280, 401, 231))
        self.table_contacts.setEditTriggers(QtWidgets.QAbstractItemView.NoEditTriggers)
        self.table_contacts.setDragDropOverwriteMode(False)
        self.table_contacts.setAlternatingRowColors(True)
        self.table_contacts.setSelectionMode(QtWidgets.QAbstractItemView.SingleSelection)
        self.table_contacts.setSelectionBehavior(QtWidgets.QAbstractItemView.SelectRows)
        self.table_contacts.setShowGrid(False)
        self.table_contacts.setObjectName("table_contacts")
        self.table_contacts.horizontalHeader().setVisible(False)
        self.table_contacts.horizontalHeader().setCascadingSectionResizes(False)
        self.table_contacts.horizontalHeader().setDefaultSectionSize(0)
        self.table_contacts.horizontalHeader().setHighlightSections(False)
        self.table_contacts.horizontalHeader().setMinimumSectionSize(0)
        self.table_contacts.horizontalHeader().setStretchLastSection(True)
        self.table_contacts.verticalHeader().setVisible(False)
        self.table_contacts.verticalHeader().setDefaultSectionSize(25)
        self.table_contacts.verticalHeader().setHighlightSections(False)
        self.table_contacts.verticalHeader().setMinimumSectionSize(25)
        self.status.raise_()
        self.identifier.raise_()
        self.title.raise_()
        self.label.raise_()
        self.label_2.raise_()
        self.label_3.raise_()
        self.submission_date.raise_()
        self.label_4.raise_()
        self.release_date.raise_()
        self.label_5.raise_()
        self.label_6.raise_()
        self.pubmed_id.raise_()
        self.label_7.raise_()
        self.doi.raise_()
        self.label_8.raise_()
        self.pub_title.raise_()
        self.label_9.raise_()
        self.label_11.raise_()
        self.label_12.raise_()
        self.line.raise_()
        self.label_51.raise_()
        self.authors_list.raise_()
        self.combo_status.raise_()
        self.label_10.raise_()
        self.label_pso.raise_()
        self.description.raise_()
        self.rm_contact.raise_()
        self.add_contact.raise_()
        self.edit_contact.raise_()
        self.table_contacts.raise_()
        self.tabWidget.addTab(self.tab_study, "")
        self.tab_investigation = QtWidgets.QWidget()
        self.tab_investigation.setObjectName("tab_investigation")
        self.label_19 = QtWidgets.QLabel(self.tab_investigation)
        self.label_19.setGeometry(QtCore.QRect(20, 150, 131, 16))
        self.label_19.setObjectName("label_19")
        self.submission_date_2 = QtWidgets.QDateEdit(self.tab_investigation)
        self.submission_date_2.setGeometry(QtCore.QRect(20, 170, 201, 25))
        self.submission_date_2.setCalendarPopup(False)
        self.submission_date_2.setObjectName("submission_date_2")
        self.release_date_2 = QtWidgets.QDateEdit(self.tab_investigation)
        self.release_date_2.setGeometry(QtCore.QRect(239, 170, 201, 25))
        self.release_date_2.setCalendarPopup(False)
        self.release_date_2.setObjectName("release_date_2")
        self.label_24 = QtWidgets.QLabel(self.tab_investigation)
        self.label_24.setGeometry(QtCore.QRect(470, 50, 211, 16))
        self.label_24.setObjectName("label_24")
        self.label_25 = QtWidgets.QLabel(self.tab_investigation)
        self.label_25.setGeometry(QtCore.QRect(20, 20, 261, 21))
        self.label_25.setStyleSheet("font: 12pt url(:/fonts/assets/fonts/Verdana.ttf);")
        self.label_25.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignTop)
        self.label_25.setObjectName("label_25")
        self.identifier_2 = QtWidgets.QLineEdit(self.tab_investigation)
        self.identifier_2.setEnabled(False)
        self.identifier_2.setGeometry(QtCore.QRect(20, 70, 420, 25))
        self.identifier_2.setStyleSheet("font: italic 10pt url(:/fonts/assets/fonts/Verdana.ttf);")
        self.identifier_2.setText("")
        self.identifier_2.setObjectName("identifier_2")
        self.label_26 = QtWidgets.QLabel(self.tab_investigation)
        self.label_26.setGeometry(QtCore.QRect(250, 150, 131, 16))
        self.label_26.setObjectName("label_26")
        self.label_27 = QtWidgets.QLabel(self.tab_investigation)
        self.label_27.setEnabled(False)
        self.label_27.setGeometry(QtCore.QRect(20, 50, 131, 16))
        self.label_27.setObjectName("label_27")
        self.title_2 = QtWidgets.QLineEdit(self.tab_investigation)
        self.title_2.setEnabled(False)
        self.title_2.setGeometry(QtCore.QRect(20, 120, 420, 25))
        self.title_2.setObjectName("title_2")
        self.label_28 = QtWidgets.QLabel(self.tab_investigation)
        self.label_28.setGeometry(QtCore.QRect(20, 100, 131, 16))
        self.label_28.setObjectName("label_28")
        self.label_29 = QtWidgets.QLabel(self.tab_investigation)
        self.label_29.setGeometry(QtCore.QRect(470, 230, 261, 31))
        self.label_29.setStyleSheet("font: 12pt url(:/fonts/assets/fonts/Verdana.ttf);")
        self.label_29.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignTop)
        self.label_29.setObjectName("label_29")
        self.pubmed_id_2 = QtWidgets.QLineEdit(self.tab_investigation)
        self.pubmed_id_2.setGeometry(QtCore.QRect(20, 280, 131, 25))
        self.pubmed_id_2.setObjectName("pubmed_id_2")
        self.line_2 = QtWidgets.QFrame(self.tab_investigation)
        self.line_2.setGeometry(QtCore.QRect(445, 260, 20, 251))
        self.line_2.setFrameShape(QtWidgets.QFrame.VLine)
        self.line_2.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_2.setObjectName("line_2")
        self.combo_status_2 = QtWidgets.QComboBox(self.tab_investigation)
        self.combo_status_2.setEnabled(False)
        self.combo_status_2.setGeometry(QtCore.QRect(20, 380, 421, 25))
        self.combo_status_2.setCurrentText("")
        self.combo_status_2.setMaxVisibleItems(10)
        self.combo_status_2.setObjectName("combo_status_2")
        self.label_32 = QtWidgets.QLabel(self.tab_investigation)
        self.label_32.setGeometry(QtCore.QRect(20, 360, 131, 16))
        self.label_32.setObjectName("label_32")
        self.label_33 = QtWidgets.QLabel(self.tab_investigation)
        self.label_33.setGeometry(QtCore.QRect(20, 230, 261, 21))
        self.label_33.setStyleSheet("font: 12pt url(:/fonts/assets/fonts/Verdana.ttf);")
        self.label_33.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignTop)
        self.label_33.setObjectName("label_33")
        self.label_36 = QtWidgets.QLabel(self.tab_investigation)
        self.label_36.setGeometry(QtCore.QRect(20, 260, 131, 16))
        self.label_36.setObjectName("label_36")
        self.doi_2 = QtWidgets.QLineEdit(self.tab_investigation)
        self.doi_2.setGeometry(QtCore.QRect(169, 280, 271, 25))
        self.doi_2.setObjectName("doi_2")
        self.pub_title_2 = QtWidgets.QLineEdit(self.tab_investigation)
        self.pub_title_2.setGeometry(QtCore.QRect(20, 330, 420, 25))
        self.pub_title_2.setText("")
        self.pub_title_2.setObjectName("pub_title_2")
        self.label_39 = QtWidgets.QLabel(self.tab_investigation)
        self.label_39.setGeometry(QtCore.QRect(20, 310, 131, 16))
        self.label_39.setObjectName("label_39")
        self.label_43 = QtWidgets.QLabel(self.tab_investigation)
        self.label_43.setGeometry(QtCore.QRect(170, 260, 131, 16))
        self.label_43.setObjectName("label_43")
        self.label_52 = QtWidgets.QLabel(self.tab_investigation)
        self.label_52.setGeometry(QtCore.QRect(20, 410, 131, 16))
        self.label_52.setObjectName("label_52")
        self.authors_list_2 = QtWidgets.QTextEdit(self.tab_investigation)
        self.authors_list_2.setEnabled(True)
        self.authors_list_2.setGeometry(QtCore.QRect(20, 430, 421, 81))
        self.authors_list_2.setStyleSheet("")
        self.authors_list_2.setObjectName("authors_list_2")
        self.status_2 = QtWidgets.QLineEdit(self.tab_investigation)
        self.status_2.setGeometry(QtCore.QRect(20, 370, 421, 41))
        self.status_2.setFrame(False)
        self.status_2.setObjectName("status_2")
        self.label_pso_2 = QtWidgets.QLabel(self.tab_investigation)
        self.label_pso_2.setGeometry(QtCore.QRect(30, 380, 401, 25))
        self.label_pso_2.setObjectName("label_pso_2")
        self.description_2 = QtWidgets.QPlainTextEdit(self.tab_investigation)
        self.description_2.setGeometry(QtCore.QRect(470, 70, 401, 121))
        self.description_2.setObjectName("description_2")
        self.add_contact_2 = QtWidgets.QPushButton(self.tab_investigation)
        self.add_contact_2.setGeometry(QtCore.QRect(800, 250, 31, 20))
        self.add_contact_2.setStyleSheet("font: 9pt url(:/fonts/assets/fonts/EBI-Functional.ttf);\n"
"font-family: \"EBI-Functional\";")
        self.add_contact_2.setObjectName("add_contact_2")
        self.table_contacts_2 = QtWidgets.QTableView(self.tab_investigation)
        self.table_contacts_2.setGeometry(QtCore.QRect(470, 280, 401, 231))
        self.table_contacts_2.setEditTriggers(QtWidgets.QAbstractItemView.NoEditTriggers)
        self.table_contacts_2.setDragDropOverwriteMode(False)
        self.table_contacts_2.setAlternatingRowColors(True)
        self.table_contacts_2.setSelectionMode(QtWidgets.QAbstractItemView.SingleSelection)
        self.table_contacts_2.setSelectionBehavior(QtWidgets.QAbstractItemView.SelectRows)
        self.table_contacts_2.setShowGrid(False)
        self.table_contacts_2.setObjectName("table_contacts_2")
        self.table_contacts_2.horizontalHeader().setVisible(False)
        self.table_contacts_2.horizontalHeader().setCascadingSectionResizes(False)
        self.table_contacts_2.horizontalHeader().setDefaultSectionSize(0)
        self.table_contacts_2.horizontalHeader().setHighlightSections(False)
        self.table_contacts_2.horizontalHeader().setMinimumSectionSize(0)
        self.table_contacts_2.horizontalHeader().setStretchLastSection(True)
        self.table_contacts_2.verticalHeader().setVisible(False)
        self.table_contacts_2.verticalHeader().setDefaultSectionSize(25)
        self.table_contacts_2.verticalHeader().setHighlightSections(False)
        self.table_contacts_2.verticalHeader().setMinimumSectionSize(25)
        self.rm_contact_2 = QtWidgets.QPushButton(self.tab_investigation)
        self.rm_contact_2.setGeometry(QtCore.QRect(840, 250, 31, 20))
        self.rm_contact_2.setStyleSheet("font: 9pt url(:/fonts/assets/fonts/EBI-Functional.ttf);\n"
"font-family: \"EBI-Functional\";")
        self.rm_contact_2.setObjectName("rm_contact_2")
        self.edit_contact_2 = QtWidgets.QPushButton(self.tab_investigation)
        self.edit_contact_2.setGeometry(QtCore.QRect(760, 250, 31, 20))
        self.edit_contact_2.setStyleSheet("font: 9pt url(:/fonts/assets/fonts/EBI-Functional.ttf);\n"
"font-family: \"EBI-Functional\";")
        self.edit_contact_2.setObjectName("edit_contact_2")
        self.status_2.raise_()
        self.label_19.raise_()
        self.submission_date_2.raise_()
        self.release_date_2.raise_()
        self.label_24.raise_()
        self.label_25.raise_()
        self.identifier_2.raise_()
        self.label_26.raise_()
        self.label_27.raise_()
        self.title_2.raise_()
        self.label_28.raise_()
        self.label_29.raise_()
        self.pubmed_id_2.raise_()
        self.line_2.raise_()
        self.combo_status_2.raise_()
        self.label_32.raise_()
        self.label_33.raise_()
        self.label_36.raise_()
        self.doi_2.raise_()
        self.pub_title_2.raise_()
        self.label_39.raise_()
        self.label_43.raise_()
        self.label_52.raise_()
        self.authors_list_2.raise_()
        self.label_pso_2.raise_()
        self.description_2.raise_()
        self.add_contact_2.raise_()
        self.table_contacts_2.raise_()
        self.rm_contact_2.raise_()
        self.edit_contact_2.raise_()
        self.tabWidget.addTab(self.tab_investigation, "")
        self.tab_misc = QtWidgets.QWidget()
        self.tab_misc.setEnabled(True)
        self.tab_misc.setObjectName("tab_misc")
        self.label_44 = QtWidgets.QLabel(self.tab_misc)
        self.label_44.setGeometry(QtCore.QRect(20, 20, 261, 16))
        self.label_44.setStyleSheet("font: 12pt url(:/fonts/assets/fonts/Verdana.ttf);")
        self.label_44.setObjectName("label_44")
        self.label_45 = QtWidgets.QLabel(self.tab_misc)
        self.label_45.setGeometry(QtCore.QRect(20, 50, 70, 55))
        self.label_45.setAlignment(QtCore.Qt.AlignCenter)
        self.label_45.setObjectName("label_45")
        self.name_organism = QtWidgets.QLineEdit(self.tab_misc)
        self.name_organism.setEnabled(True)
        self.name_organism.setGeometry(QtCore.QRect(160, 50, 610, 25))
        self.name_organism.setText("")
        self.name_organism.setObjectName("name_organism")
        self.label_46 = QtWidgets.QLabel(self.tab_misc)
        self.label_46.setGeometry(QtCore.QRect(20, 115, 70, 55))
        self.label_46.setAlignment(QtCore.Qt.AlignCenter)
        self.label_46.setWordWrap(True)
        self.label_46.setObjectName("label_46")
        self.name_organism_variant = QtWidgets.QLineEdit(self.tab_misc)
        self.name_organism_variant.setEnabled(True)
        self.name_organism_variant.setGeometry(QtCore.QRect(159, 115, 611, 25))
        self.name_organism_variant.setText("")
        self.name_organism_variant.setObjectName("name_organism_variant")
        self.name_organism_part = QtWidgets.QLineEdit(self.tab_misc)
        self.name_organism_part.setEnabled(True)
        self.name_organism_part.setGeometry(QtCore.QRect(159, 180, 611, 25))
        self.name_organism_part.setText("")
        self.name_organism_part.setObjectName("name_organism_part")
        self.label_47 = QtWidgets.QLabel(self.tab_misc)
        self.label_47.setGeometry(QtCore.QRect(20, 180, 70, 55))
        self.label_47.setAlignment(QtCore.Qt.AlignCenter)
        self.label_47.setWordWrap(True)
        self.label_47.setObjectName("label_47")
        self.label_50 = QtWidgets.QLabel(self.tab_misc)
        self.label_50.setGeometry(QtCore.QRect(20, 250, 261, 31))
        self.label_50.setStyleSheet("font: 12pt url(:/fonts/assets/fonts/Verdana.ttf);")
        self.label_50.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignTop)
        self.label_50.setObjectName("label_50")
        self.tabWidget_2 = QtWidgets.QTabWidget(self.tab_misc)
        self.tabWidget_2.setGeometry(QtCore.QRect(17, 290, 860, 211))
        self.tabWidget_2.setUsesScrollButtons(False)
        self.tabWidget_2.setObjectName("tabWidget_2")
        self.extraction = QtWidgets.QWidget()
        self.extraction.setObjectName("extraction")
        self.extraction_desc = QtWidgets.QPlainTextEdit(self.extraction)
        self.extraction_desc.setGeometry(QtCore.QRect(0, 0, 847, 180))
        self.extraction_desc.setObjectName("extraction_desc")
        self.tabWidget_2.addTab(self.extraction, "")
        self.nmr_sample = QtWidgets.QWidget()
        self.nmr_sample.setObjectName("nmr_sample")
        self.nmr_sample_desc = QtWidgets.QPlainTextEdit(self.nmr_sample)
        self.nmr_sample_desc.setGeometry(QtCore.QRect(0, 0, 847, 180))
        self.nmr_sample_desc.setObjectName("nmr_sample_desc")
        self.tabWidget_2.addTab(self.nmr_sample, "")
        self.nmr_spec = QtWidgets.QWidget()
        self.nmr_spec.setObjectName("nmr_spec")
        self.nmr_spec_desc = QtWidgets.QPlainTextEdit(self.nmr_spec)
        self.nmr_spec_desc.setGeometry(QtCore.QRect(0, 0, 847, 180))
        self.nmr_spec_desc.setObjectName("nmr_spec_desc")
        self.tabWidget_2.addTab(self.nmr_spec, "")
        self.nmr_assay = QtWidgets.QWidget()
        self.nmr_assay.setObjectName("nmr_assay")
        self.nmr_assay_desc = QtWidgets.QPlainTextEdit(self.nmr_assay)
        self.nmr_assay_desc.setGeometry(QtCore.QRect(0, 0, 847, 180))
        self.nmr_assay_desc.setObjectName("nmr_assay_desc")
        self.tabWidget_2.addTab(self.nmr_assay, "")
        self.data_trans = QtWidgets.QWidget()
        self.data_trans.setObjectName("data_trans")
        self.data_trans_desc = QtWidgets.QPlainTextEdit(self.data_trans)
        self.data_trans_desc.setGeometry(QtCore.QRect(0, 0, 847, 180))
        self.data_trans_desc.setObjectName("data_trans_desc")
        self.tabWidget_2.addTab(self.data_trans, "")
        self.metabo_id = QtWidgets.QWidget()
        self.metabo_id.setObjectName("metabo_id")
        self.metabo_id_desc = QtWidgets.QPlainTextEdit(self.metabo_id)
        self.metabo_id_desc.setGeometry(QtCore.QRect(0, 0, 847, 180))
        self.metabo_id_desc.setObjectName("metabo_id_desc")
        self.tabWidget_2.addTab(self.metabo_id, "")
        self.sample_collec = QtWidgets.QWidget()
        self.sample_collec.setObjectName("sample_collec")
        self.sample_collec_desc = QtWidgets.QPlainTextEdit(self.sample_collec)
        self.sample_collec_desc.setGeometry(QtCore.QRect(0, 0, 847, 180))
        self.sample_collec_desc.setObjectName("sample_collec_desc")
        self.tabWidget_2.addTab(self.sample_collec, "")
        self.search_organism = QtWidgets.QPushButton(self.tab_misc)
        self.search_organism.setGeometry(QtCore.QRect(780, 50, 40, 51))
        font = QtGui.QFont()
        font.setFamily("EBI-Conceptual")
        font.setPointSize(14)
        font.setBold(False)
        font.setItalic(False)
        font.setWeight(50)
        self.search_organism.setFont(font)
        self.search_organism.setStyleSheet("font: 14pt \":/fonts/assets/fonts/EBI-Conceptual.ttf\";\n"
"font-family: \"EBI-Conceptual\";")
        self.search_organism.setObjectName("search_organism")
        self.search_organism_variant = QtWidgets.QPushButton(self.tab_misc)
        self.search_organism_variant.setGeometry(QtCore.QRect(780, 115, 40, 51))
        font = QtGui.QFont()
        font.setFamily("EBI-Conceptual")
        font.setPointSize(14)
        font.setBold(False)
        font.setItalic(False)
        font.setWeight(50)
        self.search_organism_variant.setFont(font)
        self.search_organism_variant.setStyleSheet("font: 14pt \":/fonts/assets/fonts/EBI-Conceptual.ttf\";\n"
"font-family: \"EBI-Conceptual\";")
        self.search_organism_variant.setObjectName("search_organism_variant")
        self.search_organism_part = QtWidgets.QPushButton(self.tab_misc)
        self.search_organism_part.setGeometry(QtCore.QRect(780, 180, 40, 50))
        font = QtGui.QFont()
        font.setFamily("EBI-Conceptual")
        font.setPointSize(14)
        font.setBold(False)
        font.setItalic(False)
        font.setWeight(50)
        self.search_organism_part.setFont(font)
        self.search_organism_part.setStyleSheet("font: 14pt \":/fonts/assets/fonts/EBI-Conceptual.ttf\";\n"
"font-family: \"EBI-Conceptual\";")
        self.search_organism_part.setObjectName("search_organism_part")
        self.accession_organism = QtWidgets.QLineEdit(self.tab_misc)
        self.accession_organism.setEnabled(True)
        self.accession_organism.setGeometry(QtCore.QRect(399, 75, 371, 25))
        self.accession_organism.setText("")
        self.accession_organism.setObjectName("accession_organism")
        self.accession_organism_variant = QtWidgets.QLineEdit(self.tab_misc)
        self.accession_organism_variant.setEnabled(True)
        self.accession_organism_variant.setGeometry(QtCore.QRect(399, 140, 371, 25))
        self.accession_organism_variant.setStyleSheet("")
        self.accession_organism_variant.setText("")
        self.accession_organism_variant.setObjectName("accession_organism_variant")
        self.accession_organism_part = QtWidgets.QLineEdit(self.tab_misc)
        self.accession_organism_part.setEnabled(True)
        self.accession_organism_part.setGeometry(QtCore.QRect(399, 205, 371, 25))
        self.accession_organism_part.setText("")
        self.accession_organism_part.setObjectName("accession_organism_part")
        self.ref_organism_part = QtWidgets.QLineEdit(self.tab_misc)
        self.ref_organism_part.setEnabled(True)
        self.ref_organism_part.setGeometry(QtCore.QRect(160, 205, 205, 25))
        self.ref_organism_part.setObjectName("ref_organism_part")
        self.ref_organism_variant = QtWidgets.QLineEdit(self.tab_misc)
        self.ref_organism_variant.setEnabled(True)
        self.ref_organism_variant.setGeometry(QtCore.QRect(160, 140, 205, 25))
        self.ref_organism_variant.setObjectName("ref_organism_variant")
        self.ref_organism = QtWidgets.QLineEdit(self.tab_misc)
        self.ref_organism.setEnabled(True)
        self.ref_organism.setGeometry(QtCore.QRect(160, 75, 205, 25))
        self.ref_organism.setObjectName("ref_organism")
        self.rm_organism = QtWidgets.QPushButton(self.tab_misc)
        self.rm_organism.setGeometry(QtCore.QRect(830, 50, 40, 51))
        font = QtGui.QFont()
        font.setFamily("EBI-Functional")
        font.setPointSize(12)
        font.setBold(False)
        font.setItalic(False)
        font.setWeight(50)
        self.rm_organism.setFont(font)
        self.rm_organism.setStyleSheet("font: 12pt \":/fonts/assets/fonts/EBI-Functional.ttf\";\n"
"font-family: \"EBI-Functional\";")
        self.rm_organism.setObjectName("rm_organism")
        self.rm_organism_variant = QtWidgets.QPushButton(self.tab_misc)
        self.rm_organism_variant.setGeometry(QtCore.QRect(830, 115, 40, 51))
        font = QtGui.QFont()
        font.setFamily("EBI-Functional")
        font.setPointSize(12)
        font.setBold(False)
        font.setItalic(False)
        font.setWeight(50)
        self.rm_organism_variant.setFont(font)
        self.rm_organism_variant.setStyleSheet("font: 12pt \":/fonts/assets/fonts/EBI-Functional.ttf\";\n"
"font-family: \"EBI-Functional\";")
        self.rm_organism_variant.setObjectName("rm_organism_variant")
        self.rm_organism_part = QtWidgets.QPushButton(self.tab_misc)
        self.rm_organism_part.setGeometry(QtCore.QRect(830, 180, 40, 51))
        font = QtGui.QFont()
        font.setFamily("EBI-Functional")
        font.setPointSize(12)
        font.setBold(False)
        font.setItalic(False)
        font.setWeight(50)
        self.rm_organism_part.setFont(font)
        self.rm_organism_part.setStyleSheet("font: 12pt \":/fonts/assets/fonts/EBI-Functional.ttf\";\n"
"font-family: \"EBI-Functional\";")
        self.rm_organism_part.setObjectName("rm_organism_part")
        self.label_59 = QtWidgets.QLabel(self.tab_misc)
        self.label_59.setGeometry(QtCore.QRect(90, 50, 64, 25))
        self.label_59.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.label_59.setObjectName("label_59")
        self.label_60 = QtWidgets.QLabel(self.tab_misc)
        self.label_60.setGeometry(QtCore.QRect(90, 75, 64, 25))
        self.label_60.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.label_60.setObjectName("label_60")
        self.label_61 = QtWidgets.QLabel(self.tab_misc)
        self.label_61.setGeometry(QtCore.QRect(370, 80, 64, 15))
        self.label_61.setObjectName("label_61")
        self.label_62 = QtWidgets.QLabel(self.tab_misc)
        self.label_62.setGeometry(QtCore.QRect(370, 140, 64, 25))
        self.label_62.setObjectName("label_62")
        self.label_63 = QtWidgets.QLabel(self.tab_misc)
        self.label_63.setGeometry(QtCore.QRect(370, 210, 64, 15))
        self.label_63.setObjectName("label_63")
        self.label_64 = QtWidgets.QLabel(self.tab_misc)
        self.label_64.setGeometry(QtCore.QRect(90, 115, 64, 25))
        self.label_64.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.label_64.setObjectName("label_64")
        self.label_65 = QtWidgets.QLabel(self.tab_misc)
        self.label_65.setGeometry(QtCore.QRect(90, 140, 64, 25))
        self.label_65.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.label_65.setObjectName("label_65")
        self.label_66 = QtWidgets.QLabel(self.tab_misc)
        self.label_66.setGeometry(QtCore.QRect(90, 180, 64, 25))
        self.label_66.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.label_66.setObjectName("label_66")
        self.label_67 = QtWidgets.QLabel(self.tab_misc)
        self.label_67.setGeometry(QtCore.QRect(90, 206, 64, 25))
        self.label_67.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.label_67.setObjectName("label_67")
        self.tabWidget.addTab(self.tab_misc, "")
        self.tab = QtWidgets.QWidget()
        self.tab.setObjectName("tab")
        self.label_70 = QtWidgets.QLabel(self.tab)
        self.label_70.setGeometry(QtCore.QRect(370, 190, 64, 15))
        self.label_70.setObjectName("label_70")
        self.label_68 = QtWidgets.QLabel(self.tab)
        self.label_68.setGeometry(QtCore.QRect(90, 160, 64, 25))
        self.label_68.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.label_68.setObjectName("label_68")
        self.ref_solvent = QtWidgets.QLineEdit(self.tab)
        self.ref_solvent.setEnabled(True)
        self.ref_solvent.setGeometry(QtCore.QRect(160, 185, 205, 25))
        self.ref_solvent.setObjectName("ref_solvent")
        self.search_solvent = QtWidgets.QPushButton(self.tab)
        self.search_solvent.setGeometry(QtCore.QRect(780, 160, 40, 51))
        font = QtGui.QFont()
        font.setFamily("EBI-Conceptual")
        font.setPointSize(14)
        font.setBold(False)
        font.setItalic(False)
        font.setWeight(50)
        self.search_solvent.setFont(font)
        self.search_solvent.setStyleSheet("font: 14pt \":/fonts/assets/fonts/EBI-Conceptual.ttf\";\n"
"font-family: \"EBI-Conceptual\";")
        self.search_solvent.setObjectName("search_solvent")
        self.accession_solvent = QtWidgets.QLineEdit(self.tab)
        self.accession_solvent.setEnabled(True)
        self.accession_solvent.setGeometry(QtCore.QRect(399, 185, 371, 25))
        self.accession_solvent.setText("")
        self.accession_solvent.setObjectName("accession_solvent")
        self.label_48 = QtWidgets.QLabel(self.tab)
        self.label_48.setGeometry(QtCore.QRect(20, 160, 70, 55))
        self.label_48.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.label_48.setWordWrap(True)
        self.label_48.setObjectName("label_48")
        self.rm_solvent = QtWidgets.QPushButton(self.tab)
        self.rm_solvent.setGeometry(QtCore.QRect(830, 160, 40, 51))
        font = QtGui.QFont()
        font.setFamily("EBI-Functional")
        font.setPointSize(12)
        font.setBold(False)
        font.setItalic(False)
        font.setWeight(50)
        self.rm_solvent.setFont(font)
        self.rm_solvent.setStyleSheet("font: 12pt \":/fonts/assets/fonts/EBI-Functional.ttf\";\n"
"font-family: \"EBI-Functional\";")
        self.rm_solvent.setObjectName("rm_solvent")
        self.name_solvent = QtWidgets.QLineEdit(self.tab)
        self.name_solvent.setEnabled(True)
        self.name_solvent.setGeometry(QtCore.QRect(160, 160, 610, 25))
        self.name_solvent.setText("")
        self.name_solvent.setObjectName("name_solvent")
        self.label_69 = QtWidgets.QLabel(self.tab)
        self.label_69.setGeometry(QtCore.QRect(90, 185, 64, 25))
        self.label_69.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.label_69.setObjectName("label_69")
        self.label_49 = QtWidgets.QLabel(self.tab)
        self.label_49.setGeometry(QtCore.QRect(20, 130, 261, 16))
        self.label_49.setStyleSheet("font: 12pt url(:/fonts/assets/fonts/Verdana.ttf);")
        self.label_49.setObjectName("label_49")
        self.label_53 = QtWidgets.QLabel(self.tab)
        self.label_53.setGeometry(QtCore.QRect(20, 225, 91, 55))
        self.label_53.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.label_53.setWordWrap(True)
        self.label_53.setObjectName("label_53")
        self.label_57 = QtWidgets.QLabel(self.tab)
        self.label_57.setGeometry(QtCore.QRect(20, 310, 261, 16))
        self.label_57.setStyleSheet("font: 12pt url(:/fonts/assets/fonts/Verdana.ttf);")
        self.label_57.setObjectName("label_57")
        self.label_58 = QtWidgets.QLabel(self.tab)
        self.label_58.setGeometry(QtCore.QRect(20, 330, 91, 55))
        self.label_58.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.label_58.setWordWrap(True)
        self.label_58.setObjectName("label_58")
        self.ref_label = QtWidgets.QLineEdit(self.tab)
        self.ref_label.setEnabled(True)
        self.ref_label.setGeometry(QtCore.QRect(160, 355, 205, 25))
        self.ref_label.setObjectName("ref_label")
        self.accession_label = QtWidgets.QLineEdit(self.tab)
        self.accession_label.setEnabled(True)
        self.accession_label.setGeometry(QtCore.QRect(399, 355, 371, 25))
        self.accession_label.setText("")
        self.accession_label.setObjectName("accession_label")
        self.rm_label = QtWidgets.QPushButton(self.tab)
        self.rm_label.setGeometry(QtCore.QRect(830, 330, 40, 51))
        font = QtGui.QFont()
        font.setFamily("EBI-Functional")
        font.setPointSize(12)
        font.setBold(False)
        font.setItalic(False)
        font.setWeight(50)
        self.rm_label.setFont(font)
        self.rm_label.setStyleSheet("font: 12pt \":/fonts/assets/fonts/EBI-Functional.ttf\";\n"
"font-family: \"EBI-Functional\";")
        self.rm_label.setObjectName("rm_label")
        self.label_74 = QtWidgets.QLabel(self.tab)
        self.label_74.setGeometry(QtCore.QRect(370, 360, 64, 15))
        self.label_74.setObjectName("label_74")
        self.label_75 = QtWidgets.QLabel(self.tab)
        self.label_75.setGeometry(QtCore.QRect(90, 335, 64, 25))
        self.label_75.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.label_75.setObjectName("label_75")
        self.label_76 = QtWidgets.QLabel(self.tab)
        self.label_76.setGeometry(QtCore.QRect(90, 355, 64, 25))
        self.label_76.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.label_76.setObjectName("label_76")
        self.name_label = QtWidgets.QLineEdit(self.tab)
        self.name_label.setEnabled(True)
        self.name_label.setGeometry(QtCore.QRect(160, 330, 610, 25))
        self.name_label.setText("")
        self.name_label.setObjectName("name_label")
        self.search_label = QtWidgets.QPushButton(self.tab)
        self.search_label.setGeometry(QtCore.QRect(780, 330, 40, 51))
        font = QtGui.QFont()
        font.setFamily("EBI-Conceptual")
        font.setPointSize(14)
        font.setBold(False)
        font.setItalic(False)
        font.setWeight(50)
        self.search_label.setFont(font)
        self.search_label.setStyleSheet("font: 14pt \":/fonts/assets/fonts/EBI-Conceptual.ttf\";\n"
"font-family: \"EBI-Conceptual\";")
        self.search_label.setObjectName("search_label")
        self.label_54 = QtWidgets.QLabel(self.tab)
        self.label_54.setGeometry(QtCore.QRect(20, 20, 261, 16))
        self.label_54.setStyleSheet("font: 12pt url(:/fonts/assets/fonts/Verdana.ttf);")
        self.label_54.setObjectName("label_54")
        self.accession_extraction_method = QtWidgets.QLineEdit(self.tab)
        self.accession_extraction_method.setEnabled(True)
        self.accession_extraction_method.setGeometry(QtCore.QRect(399, 75, 371, 25))
        self.accession_extraction_method.setText("")
        self.accession_extraction_method.setObjectName("accession_extraction_method")
        self.label_55 = QtWidgets.QLabel(self.tab)
        self.label_55.setGeometry(QtCore.QRect(20, 44, 81, 61))
        self.label_55.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.label_55.setWordWrap(True)
        self.label_55.setObjectName("label_55")
        self.rm_extraction_method = QtWidgets.QPushButton(self.tab)
        self.rm_extraction_method.setGeometry(QtCore.QRect(830, 50, 40, 51))
        font = QtGui.QFont()
        font.setFamily("EBI-Functional")
        font.setPointSize(12)
        font.setBold(False)
        font.setItalic(False)
        font.setWeight(50)
        self.rm_extraction_method.setFont(font)
        self.rm_extraction_method.setStyleSheet("font: 12pt \":/fonts/assets/fonts/EBI-Functional.ttf\";\n"
"font-family: \"EBI-Functional\";")
        self.rm_extraction_method.setObjectName("rm_extraction_method")
        self.label_77 = QtWidgets.QLabel(self.tab)
        self.label_77.setGeometry(QtCore.QRect(90, 75, 64, 25))
        self.label_77.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.label_77.setObjectName("label_77")
        self.label_78 = QtWidgets.QLabel(self.tab)
        self.label_78.setGeometry(QtCore.QRect(370, 80, 64, 15))
        self.label_78.setObjectName("label_78")
        self.search_extraction_method = QtWidgets.QPushButton(self.tab)
        self.search_extraction_method.setGeometry(QtCore.QRect(780, 50, 40, 51))
        font = QtGui.QFont()
        font.setFamily("EBI-Conceptual")
        font.setPointSize(14)
        font.setBold(False)
        font.setItalic(False)
        font.setWeight(50)
        self.search_extraction_method.setFont(font)
        self.search_extraction_method.setStyleSheet("font: 14pt \":/fonts/assets/fonts/EBI-Conceptual.ttf\";\n"
"font-family: \"EBI-Conceptual\";")
        self.search_extraction_method.setObjectName("search_extraction_method")
        self.ref_extraction_method = QtWidgets.QLineEdit(self.tab)
        self.ref_extraction_method.setEnabled(True)
        self.ref_extraction_method.setGeometry(QtCore.QRect(160, 75, 205, 25))
        self.ref_extraction_method.setObjectName("ref_extraction_method")
        self.label_79 = QtWidgets.QLabel(self.tab)
        self.label_79.setGeometry(QtCore.QRect(90, 50, 64, 25))
        self.label_79.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.label_79.setObjectName("label_79")
        self.name_extraction_method = QtWidgets.QLineEdit(self.tab)
        self.name_extraction_method.setEnabled(True)
        self.name_extraction_method.setGeometry(QtCore.QRect(160, 50, 610, 25))
        self.name_extraction_method.setText("")
        self.name_extraction_method.setObjectName("name_extraction_method")
        self.label_56 = QtWidgets.QLabel(self.tab)
        self.label_56.setGeometry(QtCore.QRect(10, 460, 311, 55))
        self.label_56.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.label_56.setWordWrap(True)
        self.label_56.setObjectName("label_56")
        self.value_sample_pH = QtWidgets.QLineEdit(self.tab)
        self.value_sample_pH.setGeometry(QtCore.QRect(160, 240, 201, 25))
        self.value_sample_pH.setObjectName("value_sample_pH")
        self.label_71 = QtWidgets.QLabel(self.tab)
        self.label_71.setGeometry(QtCore.QRect(90, 240, 64, 25))
        self.label_71.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.label_71.setObjectName("label_71")
        self.tabWidget.addTab(self.tab, "")
        self.frame = QtWidgets.QFrame(Dialog)
        self.frame.setGeometry(QtCore.QRect(0, 0, 960, 30))
        self.frame.setStyleSheet("background: rgb(255, 255, 255)rgb(11, 123, 189);")
        self.frame.setFrameShape(QtWidgets.QFrame.Box)
        self.frame.setFrameShadow(QtWidgets.QFrame.Plain)
        self.frame.setObjectName("frame")
        self.label_22 = QtWidgets.QLabel(Dialog)
        self.label_22.setGeometry(QtCore.QRect(30, 610, 311, 16))
        self.label_22.setObjectName("label_22")
        self.buttonBox = QtWidgets.QDialogButtonBox(Dialog)
        self.buttonBox.setGeometry(QtCore.QRect(440, 606, 491, 26))
        self.buttonBox.setStandardButtons(QtWidgets.QDialogButtonBox.Apply|QtWidgets.QDialogButtonBox.Cancel|QtWidgets.QDialogButtonBox.Ok)
        self.buttonBox.setObjectName("buttonBox")

        self.retranslateUi(Dialog)
        self.tabWidget.setCurrentIndex(0)
        self.combo_status_2.setCurrentIndex(-1)
        self.tabWidget_2.setCurrentIndex(0)
        QtCore.QMetaObject.connectSlotsByName(Dialog)
        Dialog.setTabOrder(self.identifier, self.title)
        Dialog.setTabOrder(self.title, self.submission_date)
        Dialog.setTabOrder(self.submission_date, self.release_date)
        Dialog.setTabOrder(self.release_date, self.description)
        Dialog.setTabOrder(self.description, self.pubmed_id)
        Dialog.setTabOrder(self.pubmed_id, self.doi)
        Dialog.setTabOrder(self.doi, self.pub_title)
        Dialog.setTabOrder(self.pub_title, self.combo_status)
        Dialog.setTabOrder(self.combo_status, self.authors_list)
        Dialog.setTabOrder(self.authors_list, self.table_contacts)
        Dialog.setTabOrder(self.table_contacts, self.edit_contact)
        Dialog.setTabOrder(self.edit_contact, self.add_contact)
        Dialog.setTabOrder(self.add_contact, self.rm_contact)
        Dialog.setTabOrder(self.rm_contact, self.identifier_2)
        Dialog.setTabOrder(self.identifier_2, self.title_2)
        Dialog.setTabOrder(self.title_2, self.submission_date_2)
        Dialog.setTabOrder(self.submission_date_2, self.release_date_2)
        Dialog.setTabOrder(self.release_date_2, self.description_2)
        Dialog.setTabOrder(self.description_2, self.pubmed_id_2)
        Dialog.setTabOrder(self.pubmed_id_2, self.doi_2)
        Dialog.setTabOrder(self.doi_2, self.pub_title_2)
        Dialog.setTabOrder(self.pub_title_2, self.combo_status_2)
        Dialog.setTabOrder(self.combo_status_2, self.authors_list_2)
        Dialog.setTabOrder(self.authors_list_2, self.table_contacts_2)
        Dialog.setTabOrder(self.table_contacts_2, self.edit_contact_2)
        Dialog.setTabOrder(self.edit_contact_2, self.add_contact_2)
        Dialog.setTabOrder(self.add_contact_2, self.rm_contact_2)
        Dialog.setTabOrder(self.rm_contact_2, self.name_organism)
        Dialog.setTabOrder(self.name_organism, self.ref_organism)
        Dialog.setTabOrder(self.ref_organism, self.accession_organism)
        Dialog.setTabOrder(self.accession_organism, self.search_organism)
        Dialog.setTabOrder(self.search_organism, self.rm_organism)
        Dialog.setTabOrder(self.rm_organism, self.name_organism_variant)
        Dialog.setTabOrder(self.name_organism_variant, self.ref_organism_variant)
        Dialog.setTabOrder(self.ref_organism_variant, self.accession_organism_variant)
        Dialog.setTabOrder(self.accession_organism_variant, self.search_organism_variant)
        Dialog.setTabOrder(self.search_organism_variant, self.rm_organism_variant)
        Dialog.setTabOrder(self.rm_organism_variant, self.name_organism_part)
        Dialog.setTabOrder(self.name_organism_part, self.ref_organism_part)
        Dialog.setTabOrder(self.ref_organism_part, self.accession_organism_part)
        Dialog.setTabOrder(self.accession_organism_part, self.search_organism_part)
        Dialog.setTabOrder(self.search_organism_part, self.rm_organism_part)
        Dialog.setTabOrder(self.rm_organism_part, self.extraction_desc)
        Dialog.setTabOrder(self.extraction_desc, self.nmr_sample_desc)
        Dialog.setTabOrder(self.nmr_sample_desc, self.nmr_spec_desc)
        Dialog.setTabOrder(self.nmr_spec_desc, self.data_trans_desc)
        Dialog.setTabOrder(self.data_trans_desc, self.metabo_id_desc)
        Dialog.setTabOrder(self.metabo_id_desc, self.tabWidget)
        Dialog.setTabOrder(self.tabWidget, self.tabWidget_2)
        Dialog.setTabOrder(self.tabWidget_2, self.status)
        Dialog.setTabOrder(self.status, self.status_2)

    def retranslateUi(self, Dialog):
        _translate = QtCore.QCoreApplication.translate
        Dialog.setWindowTitle(_translate("Dialog", "Additional Metadata"))
        self.identifier.setPlaceholderText(_translate("Dialog", "will use study identifier name from main window"))
        self.label.setText(_translate("Dialog", "Identifier"))
        self.label_2.setText(_translate("Dialog", "Title *"))
        self.label_3.setText(_translate("Dialog", "Submission date"))
        self.submission_date.setDisplayFormat(_translate("Dialog", "yyyy-MM-dd"))
        self.label_4.setText(_translate("Dialog", "Release date"))
        self.release_date.setDisplayFormat(_translate("Dialog", "yyyy-MM-dd"))
        self.label_5.setText(_translate("Dialog", "Study"))
        self.label_6.setText(_translate("Dialog", "Study Publication"))
        self.pubmed_id.setPlaceholderText(_translate("Dialog", "e.g. 26496010"))
        self.label_7.setText(_translate("Dialog", "PubMed identifier"))
        self.doi.setPlaceholderText(_translate("Dialog", "e.g.  10.1016/j.jhep.2013.12.002"))
        self.label_8.setText(_translate("Dialog", "DOI"))
        self.label_9.setText(_translate("Dialog", "Title"))
        self.label_10.setText(_translate("Dialog", "Status"))
        self.label_11.setText(_translate("Dialog", "Description *"))
        self.label_12.setText(_translate("Dialog", "Study Contacts *"))
        self.label_51.setText(_translate("Dialog", "Authors"))
        self.label_pso.setText(_translate("Dialog", "connecting to PSO <sparontologies.net/ontologies/pso>"))
        self.rm_contact.setText(_translate("Dialog", "-"))
        self.add_contact.setText(_translate("Dialog", "+"))
        self.edit_contact.setText(_translate("Dialog", "e"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_study), _translate("Dialog", "Study"))
        self.label_19.setText(_translate("Dialog", "Submission date"))
        self.submission_date_2.setDisplayFormat(_translate("Dialog", "yyyy-MM-dd"))
        self.release_date_2.setDisplayFormat(_translate("Dialog", "yyyy-MM-dd"))
        self.label_24.setText(_translate("Dialog", "Description"))
        self.label_25.setText(_translate("Dialog", "Investigation"))
        self.identifier_2.setPlaceholderText(_translate("Dialog", "will use study identifier name from main window"))
        self.label_26.setText(_translate("Dialog", "Release date"))
        self.label_27.setText(_translate("Dialog", "Identifier"))
        self.title_2.setText(_translate("Dialog", "Investigation"))
        self.label_28.setText(_translate("Dialog", "Title"))
        self.label_29.setText(_translate("Dialog", "Investigation Contact"))
        self.pubmed_id_2.setPlaceholderText(_translate("Dialog", "e.g. 26496010"))
        self.label_32.setText(_translate("Dialog", "Status"))
        self.label_33.setText(_translate("Dialog", "Investigation Publication"))
        self.label_36.setText(_translate("Dialog", "PubMed identifier"))
        self.doi_2.setPlaceholderText(_translate("Dialog", "e.g.  10.1016/j.jhep.2013.12.002"))
        self.label_39.setText(_translate("Dialog", "Title"))
        self.label_43.setText(_translate("Dialog", "DOI"))
        self.label_52.setText(_translate("Dialog", "Authors"))
        self.label_pso_2.setText(_translate("Dialog", "connecting to PSO <sparontologies.net/ontologies/pso>"))
        self.add_contact_2.setText(_translate("Dialog", "+"))
        self.rm_contact_2.setText(_translate("Dialog", "-"))
        self.edit_contact_2.setText(_translate("Dialog", "e"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_investigation), _translate("Dialog", "Investigation"))
        self.label_44.setText(_translate("Dialog", "Characteristics *"))
        self.label_45.setText(_translate("Dialog", "Organism"))
        self.name_organism.setPlaceholderText(_translate("Dialog", "e.g. Homo sapiens"))
        self.label_46.setText(_translate("Dialog", "Organism variant"))
        self.name_organism_variant.setPlaceholderText(_translate("Dialog", "e.g. Saccharomyces cerevisiae LAN211"))
        self.name_organism_part.setPlaceholderText(_translate("Dialog", "e.g. lacrimal gland"))
        self.label_47.setText(_translate("Dialog", "Organism part"))
        self.label_50.setText(_translate("Dialog", "Protocols description *"))
        self.tabWidget_2.setTabText(self.tabWidget_2.indexOf(self.extraction), _translate("Dialog", "Extraction"))
        self.tabWidget_2.setTabText(self.tabWidget_2.indexOf(self.nmr_sample), _translate("Dialog", "NMR Sample"))
        self.tabWidget_2.setTabText(self.tabWidget_2.indexOf(self.nmr_spec), _translate("Dialog", "NMR Spectroscopy"))
        self.tabWidget_2.setTabText(self.tabWidget_2.indexOf(self.nmr_assay), _translate("Dialog", "NMR Assay"))
        self.tabWidget_2.setTabText(self.tabWidget_2.indexOf(self.data_trans), _translate("Dialog", "Data transformation"))
        self.tabWidget_2.setTabText(self.tabWidget_2.indexOf(self.metabo_id), _translate("Dialog", "Metabolite identification"))
        self.tabWidget_2.setTabText(self.tabWidget_2.indexOf(self.sample_collec), _translate("Dialog", "Sample collection"))
        self.search_organism.setText(_translate("Dialog", "o"))
        self.search_organism_variant.setText(_translate("Dialog", "o"))
        self.search_organism_part.setText(_translate("Dialog", "o"))
        self.accession_organism.setPlaceholderText(_translate("Dialog", "e.g. http://purl.obolibrary.org/obo/VTO_0011993"))
        self.accession_organism_variant.setPlaceholderText(_translate("Dialog", "e.g. http://purl.obolibrary.org/obo/NCBITaxon_1216859"))
        self.accession_organism_part.setPlaceholderText(_translate("Dialog", "e.g. http://purl.obolibrary.org/obo/UBERON_0001817"))
        self.ref_organism_part.setPlaceholderText(_translate("Dialog", "e.g. UBERON"))
        self.ref_organism_variant.setPlaceholderText(_translate("Dialog", "e.g NCBITaxon"))
        self.ref_organism.setPlaceholderText(_translate("Dialog", "e.g. VTO"))
        self.rm_organism.setText(_translate("Dialog", "d"))
        self.rm_organism_variant.setText(_translate("Dialog", "d"))
        self.rm_organism_part.setText(_translate("Dialog", "d"))
        self.label_59.setText(_translate("Dialog", "Name:"))
        self.label_60.setText(_translate("Dialog", "Ref:"))
        self.label_61.setText(_translate("Dialog", "IRI:"))
        self.label_62.setText(_translate("Dialog", "IRI:"))
        self.label_63.setText(_translate("Dialog", "IRI:"))
        self.label_64.setText(_translate("Dialog", "Name:"))
        self.label_65.setText(_translate("Dialog", "Ref:"))
        self.label_66.setText(_translate("Dialog", "Name:"))
        self.label_67.setText(_translate("Dialog", "Ref:"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_misc), _translate("Dialog", "Experiments"))
        self.label_70.setText(_translate("Dialog", "IRI:"))
        self.label_68.setText(_translate("Dialog", "Name:"))
        self.ref_solvent.setPlaceholderText(_translate("Dialog", "e.g. CHEBI"))
        self.search_solvent.setText(_translate("Dialog", "o"))
        self.accession_solvent.setPlaceholderText(_translate("Dialog", "e.g. http://purl.obolibrary.org/obo/CHEBI_35702"))
        self.label_48.setText(_translate("Dialog", "Solvent"))
        self.rm_solvent.setText(_translate("Dialog", "d"))
        self.name_solvent.setPlaceholderText(_translate("Dialog", "e.g. diethyl ether"))
        self.label_69.setText(_translate("Dialog", "Ref:"))
        self.label_49.setText(_translate("Dialog", "Sample"))
        self.label_53.setText(_translate("Dialog", "Sample pH"))
        self.label_57.setText(_translate("Dialog", "NMR"))
        self.label_58.setText(_translate("Dialog", "Label"))
        self.ref_label.setPlaceholderText(_translate("Dialog", "e.g. CHEBI"))
        self.accession_label.setPlaceholderText(_translate("Dialog", "e.g. http://purl.obolibrary.org/obo/CHEBI_33608"))
        self.rm_label.setText(_translate("Dialog", "d"))
        self.label_74.setText(_translate("Dialog", "IRI:"))
        self.label_75.setText(_translate("Dialog", "Name:"))
        self.label_76.setText(_translate("Dialog", "Ref:"))
        self.name_label.setPlaceholderText(_translate("Dialog", "e.g. hydrogen molecular entity"))
        self.search_label.setText(_translate("Dialog", "o"))
        self.label_54.setText(_translate("Dialog", "Extraction"))
        self.accession_extraction_method.setPlaceholderText(_translate("Dialog", "e.g. http://purl.obolibrary.org/obo/CHMO_0002524"))
        self.label_55.setText(_translate("Dialog", "Extraction method (1)"))
        self.rm_extraction_method.setText(_translate("Dialog", "d"))
        self.label_77.setText(_translate("Dialog", "Ref:"))
        self.label_78.setText(_translate("Dialog", "IRI:"))
        self.search_extraction_method.setText(_translate("Dialog", "o"))
        self.ref_extraction_method.setPlaceholderText(_translate("Dialog", "e.g. CHMO"))
        self.label_79.setText(_translate("Dialog", "Name:"))
        self.name_extraction_method.setPlaceholderText(_translate("Dialog", "e.g. Dual-phase extraction"))
        self.label_56.setText(_translate("Dialog", "(1): If no extraction method was used, put N/A in the Name field instead of leaving it blank."))
        self.label_71.setText(_translate("Dialog", "Value:"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab), _translate("Dialog", "Material / Methods"))
        self.label_22.setText(_translate("Dialog", "*: Fields required by a MetaboLights study"))

import resources_rc



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'qt/ols.ui'
#
# Created by: PyQt5 UI code generator 5.7
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_Dialog(object):
    def setupUi(self, Dialog):
        Dialog.setObjectName("Dialog")
        Dialog.resize(640, 480)
        Dialog.setMinimumSize(QtCore.QSize(640, 480))
        Dialog.setMaximumSize(QtCore.QSize(640, 480))
        self.buttonBox = QtWidgets.QDialogButtonBox(Dialog)
        self.buttonBox.setGeometry(QtCore.QRect(440, 445, 180, 30))
        self.buttonBox.setOrientation(QtCore.Qt.Horizontal)
        self.buttonBox.setStandardButtons(QtWidgets.QDialogButtonBox.Cancel|QtWidgets.QDialogButtonBox.Ok)
        self.buttonBox.setObjectName("buttonBox")
        self.queryLine = QtWidgets.QLineEdit(Dialog)
        self.queryLine.setGeometry(QtCore.QRect(10, 30, 511, 25))
        self.queryLine.setInputMethodHints(QtCore.Qt.ImhLatinOnly)
        self.queryLine.setClearButtonEnabled(False)
        self.queryLine.setObjectName("queryLine")
        self.labelQuery = QtWidgets.QLabel(Dialog)
        self.labelQuery.setGeometry(QtCore.QRect(10, 10, 64, 16))
        self.labelQuery.setObjectName("labelQuery")
        self.searchButton = QtWidgets.QPushButton(Dialog)
        self.searchButton.setGeometry(QtCore.QRect(540, 30, 80, 26))
        self.searchButton.setStyleSheet("font: 14pt url(:/fonts/assets/fonts/EBI-Functional.ttf);\n"
"font-family: \"EBI-Functional\";")
        self.searchButton.setDefault(True)
        self.searchButton.setObjectName("searchButton")
        self.description = QtWidgets.QTextEdit(Dialog)
        self.description.setGeometry(QtCore.QRect(390, 310, 241, 131))
        self.description.setLineWrapColumnOrWidth(0)
        self.description.setTextInteractionFlags(QtCore.Qt.LinksAccessibleByKeyboard|QtCore.Qt.LinksAccessibleByMouse|QtCore.Qt.TextBrowserInteraction|QtCore.Qt.TextSelectableByKeyboard|QtCore.Qt.TextSelectableByMouse)
        self.description.setObjectName("description")
        self.ontoTree = QtWidgets.QTreeView(Dialog)
        self.ontoTree.setGeometry(QtCore.QRect(10, 100, 361, 341))
        self.ontoTree.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.ontoTree.setEditTriggers(QtWidgets.QAbstractItemView.NoEditTriggers)
        self.ontoTree.setAutoExpandDelay(0)
        self.ontoTree.setObjectName("ontoTree")
        self.labelIri = QtWidgets.QLabel(Dialog)
        self.labelIri.setGeometry(QtCore.QRect(390, 220, 64, 16))
        self.labelIri.setObjectName("labelIri")
        self.labelName = QtWidgets.QLabel(Dialog)
        self.labelName.setGeometry(QtCore.QRect(390, 80, 64, 16))
        self.labelName.setObjectName("labelName")
        self.labelPrefix = QtWidgets.QLabel(Dialog)
        self.labelPrefix.setGeometry(QtCore.QRect(390, 170, 151, 16))
        self.labelPrefix.setObjectName("labelPrefix")
        self.iri = QtWidgets.QTextEdit(Dialog)
        self.iri.setGeometry(QtCore.QRect(389, 240, 241, 41))
        self.iri.setTextInteractionFlags(QtCore.Qt.LinksAccessibleByKeyboard|QtCore.Qt.LinksAccessibleByMouse|QtCore.Qt.TextBrowserInteraction|QtCore.Qt.TextSelectableByKeyboard|QtCore.Qt.TextSelectableByMouse)
        self.iri.setObjectName("iri")
        self.value = QtWidgets.QTextEdit(Dialog)
        self.value.setGeometry(QtCore.QRect(389, 100, 241, 61))
        self.value.setLineWrapColumnOrWidth(0)
        self.value.setTextInteractionFlags(QtCore.Qt.LinksAccessibleByKeyboard|QtCore.Qt.LinksAccessibleByMouse|QtCore.Qt.TextBrowserInteraction|QtCore.Qt.TextSelectableByKeyboard|QtCore.Qt.TextSelectableByMouse)
        self.value.setObjectName("value")
        self.labelDescription = QtWidgets.QLabel(Dialog)
        self.labelDescription.setGeometry(QtCore.QRect(390, 290, 120, 16))
        self.labelDescription.setObjectName("labelDescription")
        self.labelResults = QtWidgets.QLabel(Dialog)
        self.labelResults.setGeometry(QtCore.QRect(10, 80, 64, 16))
        self.labelResults.setObjectName("labelResults")
        self.line = QtWidgets.QFrame(Dialog)
        self.line.setGeometry(QtCore.QRect(7, 60, 621, 20))
        self.line.setFrameShape(QtWidgets.QFrame.HLine)
        self.line.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line.setObjectName("line")
        self.labelType = QtWidgets.QLabel(Dialog)
        self.labelType.setGeometry(QtCore.QRect(520, 170, 100, 16))
        self.labelType.setObjectName("labelType")
        self.prefix = QtWidgets.QLineEdit(Dialog)
        self.prefix.setGeometry(QtCore.QRect(390, 190, 121, 25))
        self.prefix.setReadOnly(True)
        self.prefix.setObjectName("prefix")
        self.type = QtWidgets.QLineEdit(Dialog)
        self.type.setGeometry(QtCore.QRect(520, 190, 110, 25))
        self.type.setReadOnly(True)
        self.type.setObjectName("type")

        self.retranslateUi(Dialog)
        QtCore.QMetaObject.connectSlotsByName(Dialog)

    def retranslateUi(self, Dialog):
        _translate = QtCore.QCoreApplication.translate
        Dialog.setWindowTitle(_translate("Dialog", "Ontology Lookup Service"))
        self.queryLine.setPlaceholderText(_translate("Dialog", "e.g. Mus Musculus,  spleen primordium, rhodopsin..."))
        self.labelQuery.setText(_translate("Dialog", "Query"))
        self.searchButton.setText(_translate("Dialog", "1"))
        self.labelIri.setText(_translate("Dialog", "IRI"))
        self.labelName.setText(_translate("Dialog", "Name"))
        self.labelPrefix.setText(_translate("Dialog", "Ontology Prefix"))
        self.labelDescription.setText(_translate("Dialog", "Description"))
        self.labelResults.setText(_translate("Dialog", "Results"))
        self.labelType.setText(_translate("Dialog", "Item Type"))

import resources_rc
